/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmcarousel.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import com.unis.homePage.modular.hmcarousel.param.BizHmCarouselAddParam;
import com.unis.homePage.modular.hmcarousel.param.BizHmCarouselEditParam;
import com.unis.homePage.modular.hmcarousel.param.BizHmCarouselIdParam;
import com.unis.homePage.modular.hmcarousel.param.BizHmCarouselPageParam;
import com.unis.homePage.modular.hmcarousel.service.BizHmCarouselService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-头条轮播管理表控制器
 *
 * @author shine
 * @date  2024/05/20 19:25
 */
@Api(tags = "首页管理-头条轮播管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizHmCarouselController {

    @Resource
    private BizHmCarouselService bizHmCarouselService;

    /**
     * 获取首页管理-头条轮播管理表分页
     *
     * @author shine
     * @date  2024/05/20 19:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取首页管理-头条轮播管理表分页")
    //@SaCheckPermission("/homePage/hmcarousel/page")
    @GetMapping("/homePage/hmcarousel/page")
    public CommonResult<Page<BizHmCarousel>> page(BizHmCarouselPageParam bizHmCarouselPageParam) {
        return CommonResult.data(bizHmCarouselService.page(bizHmCarouselPageParam));
    }

    /**
     * 添加首页管理-头条轮播管理表
     *
     * @author shine
     * @date  2024/05/20 19:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加首页管理-头条轮播管理表")
    @CommonLog("添加首页管理-头条轮播管理表")
    //@SaCheckPermission("/homePage/hmcarousel/add")
    @PostMapping("/homePage/hmcarousel/add")
    public CommonResult<String> add(@RequestBody @Valid BizHmCarouselAddParam bizHmCarouselAddParam) {
        bizHmCarouselService.add(bizHmCarouselAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑首页管理-头条轮播管理表
     *
     * @author shine
     * @date  2024/05/20 19:25
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑首页管理-头条轮播管理表")
    @CommonLog("编辑首页管理-头条轮播管理表")
    //@SaCheckPermission("/homePage/hmcarousel/edit")
    @PostMapping("/homePage/hmcarousel/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizHmCarouselEditParam bizHmCarouselEditParam) {
        bizHmCarouselService.edit(bizHmCarouselEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除首页管理-头条轮播管理表
     *
     * @author shine
     * @date  2024/05/20 19:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除首页管理-头条轮播管理表")
    @CommonLog("删除首页管理-头条轮播管理表")
    //@SaCheckPermission("/homePage/hmcarousel/delete")
    @PostMapping("/homePage/hmcarousel/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizHmCarouselIdParam> bizHmCarouselIdParamList) {
        bizHmCarouselService.delete(bizHmCarouselIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取首页管理-头条轮播管理表详情
     *
     * @author shine
     * @date  2024/05/20 19:25
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取首页管理-头条轮播管理表详情")
    //@SaCheckPermission("/homePage/hmcarousel/detail")
    @GetMapping("/homePage/hmcarousel/detail")
    public CommonResult<BizHmCarousel> detail(@Valid BizHmCarouselIdParam bizHmCarouselIdParam) {
        return CommonResult.data(bizHmCarouselService.detail(bizHmCarouselIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/homePage/hmcarousel/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizHmCarousel> list) {
        bizHmCarouselService.batchUpdateStatus(list);
        return CommonResult.ok();
    }

}
