/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmcarouselconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmcarouselconfig.entity.BizHmCarouselConfig;
import com.unis.homePage.modular.hmcarouselconfig.mapper.BizHmCarouselConfigMapper;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigAddParam;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigEditParam;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigIdParam;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigPageParam;
import com.unis.homePage.modular.hmcarouselconfig.service.BizHmCarouselConfigService;

import java.util.List;
import java.util.Map;

/**
 * 首页管理-轮播图配置表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:23
 **/
@Service
public class BizHmCarouselConfigServiceImpl extends ServiceImpl<BizHmCarouselConfigMapper, BizHmCarouselConfig> implements BizHmCarouselConfigService {

    @Override
    public Page<BizHmCarouselConfig> page(BizHmCarouselConfigPageParam bizHmCarouselConfigPageParam) {
        QueryWrapper<BizHmCarouselConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmCarouselConfigPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizHmCarouselConfig::getStatus, bizHmCarouselConfigPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmCarouselConfigPageParam.getSortField(), bizHmCarouselConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmCarouselConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmCarouselConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmCarouselConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmCarouselConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmCarouselConfigAddParam bizHmCarouselConfigAddParam) {
        BizHmCarouselConfig bizHmCarouselConfig = BeanUtil.toBean(bizHmCarouselConfigAddParam, BizHmCarouselConfig.class);
        this.save(bizHmCarouselConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmCarouselConfigEditParam bizHmCarouselConfigEditParam) {
        BizHmCarouselConfig bizHmCarouselConfig = this.queryEntity(bizHmCarouselConfigEditParam.getId());
        BeanUtil.copyProperties(bizHmCarouselConfigEditParam, bizHmCarouselConfig);
        this.updateById(bizHmCarouselConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmCarouselConfigIdParam> bizHmCarouselConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmCarouselConfigIdParamList, BizHmCarouselConfigIdParam::getId));
    }

    @Override
    public BizHmCarouselConfig detail(BizHmCarouselConfigIdParam bizHmCarouselConfigIdParam) {
        return this.queryEntity(bizHmCarouselConfigIdParam.getId());
    }

    @Override
    public BizHmCarouselConfig queryEntity(String id) {
        BizHmCarouselConfig bizHmCarouselConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmCarouselConfig)) {
            throw new CommonException("首页管理-轮播图配置表不存在，id值为：{}", id);
        }
        return bizHmCarouselConfig;
    }


}
