/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmgovernmentaffairsconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.entity.BizHmGovernmentAffairsConfig;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.mapper.BizHmGovernmentAffairsConfigMapper;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.param.BizHmGovernmentAffairsConfigAddParam;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.param.BizHmGovernmentAffairsConfigEditParam;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.param.BizHmGovernmentAffairsConfigIdParam;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.param.BizHmGovernmentAffairsConfigPageParam;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.service.BizHmGovernmentAffairsConfigService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 首页管理-政务公开模块配置表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:32
 **/
@Service
public class BizHmGovernmentAffairsConfigServiceImpl extends ServiceImpl<BizHmGovernmentAffairsConfigMapper, BizHmGovernmentAffairsConfig> implements BizHmGovernmentAffairsConfigService {

    @Resource
    private BizHmGovernmentAffairsConfigMapper bizHmGovernmentAffairsConfigMapper;
    @Override
    public Page<BizHmGovernmentAffairsConfig> page(BizHmGovernmentAffairsConfigPageParam bizHmGovernmentAffairsConfigPageParam) {
        QueryWrapper<BizHmGovernmentAffairsConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmGovernmentAffairsConfigPageParam.getType())) {
            queryWrapper.lambda().eq(BizHmGovernmentAffairsConfig::getType, bizHmGovernmentAffairsConfigPageParam.getType());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmGovernmentAffairsConfigPageParam.getSortField(), bizHmGovernmentAffairsConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmGovernmentAffairsConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmGovernmentAffairsConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmGovernmentAffairsConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmGovernmentAffairsConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmGovernmentAffairsConfigAddParam bizHmGovernmentAffairsConfigAddParam) {
        BizHmGovernmentAffairsConfig bizHmGovernmentAffairsConfig = BeanUtil.toBean(bizHmGovernmentAffairsConfigAddParam, BizHmGovernmentAffairsConfig.class);
        this.save(bizHmGovernmentAffairsConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmGovernmentAffairsConfigEditParam bizHmGovernmentAffairsConfigEditParam) {
        BizHmGovernmentAffairsConfig bizHmGovernmentAffairsConfig = this.queryEntity(bizHmGovernmentAffairsConfigEditParam.getId());
        BeanUtil.copyProperties(bizHmGovernmentAffairsConfigEditParam, bizHmGovernmentAffairsConfig);
        this.updateById(bizHmGovernmentAffairsConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmGovernmentAffairsConfigIdParam> bizHmGovernmentAffairsConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmGovernmentAffairsConfigIdParamList, BizHmGovernmentAffairsConfigIdParam::getId));
    }

    @Override
    public BizHmGovernmentAffairsConfig detail(BizHmGovernmentAffairsConfigIdParam bizHmGovernmentAffairsConfigIdParam) {
        return this.queryEntity(bizHmGovernmentAffairsConfigIdParam.getId());
    }

    @Override
    public BizHmGovernmentAffairsConfig queryEntity(String id) {
        BizHmGovernmentAffairsConfig bizHmGovernmentAffairsConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmGovernmentAffairsConfig)) {
            throw new CommonException("首页管理-政务公开模块配置表不存在，id值为：{}", id);
        }
        return bizHmGovernmentAffairsConfig;
    }

    @Override
    public void disposition(List<BizHmGovernmentAffairsConfigAddParam> addParamList) {
        bizHmGovernmentAffairsConfigMapper.deleteAll();
        for(BizHmGovernmentAffairsConfigAddParam bizHmGovernmentAffairsConfigAddParam:addParamList){
            BizHmGovernmentAffairsConfig bizHmGovernmentAffairsConfig = BeanUtil.toBean(bizHmGovernmentAffairsConfigAddParam, BizHmGovernmentAffairsConfig.class);
            this.save(bizHmGovernmentAffairsConfig);
        }
    }

    @Override
    public List<BizHmGovernmentAffairsConfig> getList(BizHmGovernmentAffairsConfigPageParam bizHmGovernmentAffairsConfigPageParam) {
        QueryWrapper<BizHmGovernmentAffairsConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmGovernmentAffairsConfigPageParam.getType())) {
            queryWrapper.lambda().eq(BizHmGovernmentAffairsConfig::getType, bizHmGovernmentAffairsConfigPageParam.getType());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmGovernmentAffairsConfigPageParam.getSortField(), bizHmGovernmentAffairsConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmGovernmentAffairsConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmGovernmentAffairsConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmGovernmentAffairsConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizHmGovernmentAffairsConfig::getId);
        }
        return this.list(queryWrapper);
    }
}
