/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmimagenews.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.homePage.modular.hmimagenews.entity.BizHmImageNews;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsAddParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsEditParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsIdParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsPageParam;
import com.unis.homePage.modular.hmimagenews.service.BizHmImageNewsService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 首页管理-图片新闻管理表控制器
 *
 * @author shine
 * @date  2024/05/20 19:33
 */
@Api(tags = "首页管理-图片新闻管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizHmImageNewsController {

    @Resource
    private BizHmImageNewsService bizHmImageNewsService;

    /**
     * 获取首页管理-图片新闻管理表分页
     *
     * @author shine
     * @date  2024/05/20 19:33
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取首页管理-图片新闻管理表分页")
    @GetMapping("/homePage/hmimagenews/page")
    public CommonResult<Page<BizHmImageNews>> page(BizHmImageNewsPageParam bizHmImageNewsPageParam) {
        return CommonResult.data(bizHmImageNewsService.page(bizHmImageNewsPageParam));
    }

    /**
     * 添加首页管理-图片新闻管理表
     *
     * @author shine
     * @date  2024/05/20 19:33
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加首页管理-图片新闻管理表")
    @CommonLog("添加首页管理-图片新闻管理表")
    @PostMapping("/homePage/hmimagenews/add")
    public CommonResult<String> add(@RequestBody @Valid BizHmImageNewsAddParam bizHmImageNewsAddParam) {
        bizHmImageNewsService.add(bizHmImageNewsAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑首页管理-图片新闻管理表
     *
     * @author shine
     * @date  2024/05/20 19:33
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑首页管理-图片新闻管理表")
    @CommonLog("编辑首页管理-图片新闻管理表")
    @PostMapping("/homePage/hmimagenews/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizHmImageNewsEditParam bizHmImageNewsEditParam) {
        if(ObjectUtil.isNotEmpty(bizHmImageNewsEditParam.getNewsSort())){
            //查询 有几条数据已排序  0取消排序 1 2 3 排序
            QueryWrapper<BizHmImageNews> queryWrapper = new QueryWrapper<>();
            queryWrapper.gt("news_sort",0);
            queryWrapper.lt("news_sort",4);
            List<BizHmImageNews> list = bizHmImageNewsService.list(queryWrapper);
            if(list.size()>0){
                long newsSortCount = list.stream() // 创建流
                        .filter(BizHmImageNews -> bizHmImageNewsEditParam.getNewsSort().equals(BizHmImageNews.getNewsSort())) // 过滤出具有特定状态的数量
                        .count(); // 统计数量
                int newsSortCountInt = (int)newsSortCount;
                if(newsSortCountInt > 0){
                    return CommonResult.data("该排序已存在");
                }else{
                    bizHmImageNewsService.edit(bizHmImageNewsEditParam);
                }
            }else{
                bizHmImageNewsService.edit(bizHmImageNewsEditParam);
            }
        }else{
            bizHmImageNewsService.edit(bizHmImageNewsEditParam);
        }
        return CommonResult.ok();
    }

    /**
     * 删除首页管理-图片新闻管理表
     *
     * @author shine
     * @date  2024/05/20 19:33
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除首页管理-图片新闻管理表")
    @CommonLog("删除首页管理-图片新闻管理表")
    @PostMapping("/homePage/hmimagenews/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizHmImageNewsIdParam> bizHmImageNewsIdParamList) {
        bizHmImageNewsService.delete(bizHmImageNewsIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取首页管理-图片新闻管理表详情
     *
     * @author shine
     * @date  2024/05/20 19:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取首页管理-图片新闻管理表详情")
    @GetMapping("/homePage/hmimagenews/detail")
    public CommonResult<BizHmImageNews> detail(@Valid BizHmImageNewsIdParam bizHmImageNewsIdParam) {
        return CommonResult.data(bizHmImageNewsService.detail(bizHmImageNewsIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/homePage/hmimagenews/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizHmImageNews> list) {
        String res = bizHmImageNewsService.batchUpdateStatus(list);
        return CommonResult.data(res);
    }
}
