/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmimagenews.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmimagenews.entity.BizHmImageNews;
import com.unis.homePage.modular.hmimagenews.mapper.BizHmImageNewsMapper;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsAddParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsEditParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsIdParam;
import com.unis.homePage.modular.hmimagenews.param.BizHmImageNewsPageParam;
import com.unis.homePage.modular.hmimagenews.service.BizHmImageNewsService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-图片新闻管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:33
 **/
@Service
public class BizHmImageNewsServiceImpl extends ServiceImpl<BizHmImageNewsMapper, BizHmImageNews> implements BizHmImageNewsService {

    @Resource
    private BizHmImageNewsMapper bizHmImageNewsMapper;
    @Override
    public Page<BizHmImageNews> page(BizHmImageNewsPageParam bizHmImageNewsPageParam) {
        QueryWrapper<BizHmImageNews> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmImageNewsPageParam.getNewsTitle())) {
            queryWrapper.lambda().like(BizHmImageNews::getNewsTitle, bizHmImageNewsPageParam.getNewsTitle());
        }
        if(ObjectUtil.isNotEmpty(bizHmImageNewsPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizHmImageNews::getStatus, bizHmImageNewsPageParam.getStatus());
        }

        queryWrapper.last(" ORDER BY IFNULL(news_sort,4) asc ,publish_time DESC");

        Page<BizHmImageNews> pageList = this.page(CommonPageRequest.defaultPage(), queryWrapper);

        QueryWrapper<BizHmImageNews> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.gt("news_sort",0);
        queryWrapper1.lt("news_sort",4);
        List<BizHmImageNews> pxList = this.list(queryWrapper1);

        int pxCountInt = pxList.size();

        for (int i=0;i<pageList.getRecords().size();i++) {
             if(pxCountInt == 3 && i <3 ){
                 pageList.getRecords().get(i).setFlag(false);
             }else if(pxCountInt <3){
                 pageList.getRecords().get(i).setFlag(false);
             }else{
                 pageList.getRecords().get(i).setFlag(true);
             }
        }

        return pageList;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmImageNewsAddParam bizHmImageNewsAddParam) {
        BizHmImageNews bizHmImageNews = BeanUtil.toBean(bizHmImageNewsAddParam, BizHmImageNews.class);
        this.save(bizHmImageNews);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmImageNewsEditParam bizHmImageNewsEditParam) {
        BizHmImageNews bizHmImageNews = this.queryEntity(bizHmImageNewsEditParam.getId());
        BeanUtil.copyProperties(bizHmImageNewsEditParam, bizHmImageNews);
        bizHmImageNewsMapper.updateByIdNew(bizHmImageNews);

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmImageNewsIdParam> bizHmImageNewsIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmImageNewsIdParamList, BizHmImageNewsIdParam::getId));
    }

    @Override
    public BizHmImageNews detail(BizHmImageNewsIdParam bizHmImageNewsIdParam) {
        return this.queryEntity(bizHmImageNewsIdParam.getId());
    }

    @Override
    public BizHmImageNews queryEntity(String id) {
        BizHmImageNews bizHmImageNews = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmImageNews)) {
            throw new CommonException("首页管理-图片新闻管理表不存在，id值为：{}", id);
        }
        return bizHmImageNews;
    }

    @Override
    public String batchUpdateStatus(List<BizHmImageNews> list) {

        //2：提交（启用）；3：禁用；
        Integer qyStatus = 2;
        //Integer jyStatus = 3;

        //启用的数量
        long qyCount = list.stream() // 创建流
                .filter(BizHmImageNews -> qyStatus.equals(BizHmImageNews.getStatus())) // 过滤出具有特定状态的数量
                .count(); // 统计数量
        int qyCountInt = (int)qyCount;

        //禁用的数量
        /*long jyCount = list.stream() // 创建流
                .filter(BizHmImageNews -> jyStatus.equals(BizHmImageNews.getStatus())) // 过滤出具有特定状态的数量
                .count(); // 统计数量
        int jyCountInt = (int)jyCount;*/

        //列表中 现在启用的数量
        QueryWrapper<BizHmImageNews> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status",2);
        List<BizHmImageNews> nowList = this.list(queryWrapper);

        if(qyCountInt + nowList.size() > 3 ){ // 只允许 《= 3
             return "门户网站首页仅限展示3张图片";
        }else{
            for(BizHmImageNews bizHmImageNews:list){
                this.updateById(bizHmImageNews);
            }
            return "成功";
        }
    }
}
