/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hminteractionconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.entity.BizHmGovernmentAffairsConfig;
import com.unis.homePage.modular.hmgovernmentaffairsconfig.param.BizHmGovernmentAffairsConfigAddParam;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hminteractionconfig.entity.BizHmInteractionConfig;
import com.unis.homePage.modular.hminteractionconfig.mapper.BizHmInteractionConfigMapper;
import com.unis.homePage.modular.hminteractionconfig.param.BizHmInteractionConfigAddParam;
import com.unis.homePage.modular.hminteractionconfig.param.BizHmInteractionConfigEditParam;
import com.unis.homePage.modular.hminteractionconfig.param.BizHmInteractionConfigIdParam;
import com.unis.homePage.modular.hminteractionconfig.param.BizHmInteractionConfigPageParam;
import com.unis.homePage.modular.hminteractionconfig.service.BizHmInteractionConfigService;

import javax.annotation.Resource;
import java.util.List;

/**
 * 首页管理-互动交流模块配置表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:33
 **/
@Service
public class BizHmInteractionConfigServiceImpl extends ServiceImpl<BizHmInteractionConfigMapper, BizHmInteractionConfig> implements BizHmInteractionConfigService {

    @Resource
    private BizHmInteractionConfigMapper bizHmInteractionConfigMapper;
    @Override
    public Page<BizHmInteractionConfig> page(BizHmInteractionConfigPageParam bizHmInteractionConfigPageParam) {
        QueryWrapper<BizHmInteractionConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmInteractionConfigPageParam.getType())) {
            queryWrapper.lambda().eq(BizHmInteractionConfig::getType, bizHmInteractionConfigPageParam.getType());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmInteractionConfigPageParam.getSortField(), bizHmInteractionConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmInteractionConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmInteractionConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmInteractionConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmInteractionConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmInteractionConfigAddParam bizHmInteractionConfigAddParam) {
        BizHmInteractionConfig bizHmInteractionConfig = BeanUtil.toBean(bizHmInteractionConfigAddParam, BizHmInteractionConfig.class);
        this.save(bizHmInteractionConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmInteractionConfigEditParam bizHmInteractionConfigEditParam) {
        BizHmInteractionConfig bizHmInteractionConfig = this.queryEntity(bizHmInteractionConfigEditParam.getId());
        BeanUtil.copyProperties(bizHmInteractionConfigEditParam, bizHmInteractionConfig);
        this.updateById(bizHmInteractionConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmInteractionConfigIdParam> bizHmInteractionConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmInteractionConfigIdParamList, BizHmInteractionConfigIdParam::getId));
    }

    @Override
    public BizHmInteractionConfig detail(BizHmInteractionConfigIdParam bizHmInteractionConfigIdParam) {
        return this.queryEntity(bizHmInteractionConfigIdParam.getId());
    }

    @Override
    public BizHmInteractionConfig queryEntity(String id) {
        BizHmInteractionConfig bizHmInteractionConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmInteractionConfig)) {
            throw new CommonException("首页管理-互动交流模块配置表不存在，id值为：{}", id);
        }
        return bizHmInteractionConfig;
    }

    @Override
    public void disposition(List<BizHmInteractionConfigAddParam> addParamList) {
        bizHmInteractionConfigMapper.deleteAll();
        for(BizHmInteractionConfigAddParam bizHmInteractionConfigAddParam:addParamList){
            BizHmInteractionConfig bizHmInteractionConfig = BeanUtil.toBean(bizHmInteractionConfigAddParam, BizHmInteractionConfig.class);
            this.save(bizHmInteractionConfig);
        }
    }
}
