/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmpartyhistoryedu.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigPageParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.homePage.modular.hmpartyhistoryedu.entity.BizHmPartyHistoryEdu;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduAddParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduEditParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduIdParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduPageParam;
import com.unis.homePage.modular.hmpartyhistoryedu.service.BizHmPartyHistoryEduService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-党史学习教育表控制器
 *
 * @author shine
 * @date  2024/05/20 19:35
 */
@Api(tags = "首页管理-党史学习教育表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizHmPartyHistoryEduController {

    @Resource
    private BizHmPartyHistoryEduService bizHmPartyHistoryEduService;

    /**
     * 获取首页管理-党史学习教育表分页
     *
     * @author shine
     * @date  2024/05/20 19:35
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取首页管理-党史学习教育表分页")
    @GetMapping("/homePage/hmpartyhistoryedu/page")
    public CommonResult<Page<BizHmPartyHistoryEdu>> page(BizHmPartyHistoryEduPageParam bizHmPartyHistoryEduPageParam) {
        return CommonResult.data(bizHmPartyHistoryEduService.page(bizHmPartyHistoryEduPageParam));
    }

    /**
     * 添加首页管理-党史学习教育表
     *
     * @author shine
     * @date  2024/05/20 19:35
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加首页管理-党史学习教育表")
    @CommonLog("添加首页管理-党史学习教育表")
    @PostMapping("/homePage/hmpartyhistoryedu/add")
    public CommonResult<String> add(@RequestBody @Valid BizHmPartyHistoryEduAddParam bizHmPartyHistoryEduAddParam) {
        bizHmPartyHistoryEduService.add(bizHmPartyHistoryEduAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑首页管理-党史学习教育表
     *
     * @author shine
     * @date  2024/05/20 19:35
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑首页管理-党史学习教育表")
    @CommonLog("编辑首页管理-党史学习教育表")
    @PostMapping("/homePage/hmpartyhistoryedu/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizHmPartyHistoryEduEditParam bizHmPartyHistoryEduEditParam) {
        bizHmPartyHistoryEduService.edit(bizHmPartyHistoryEduEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除首页管理-党史学习教育表
     *
     * @author shine
     * @date  2024/05/20 19:35
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除首页管理-党史学习教育表")
    @CommonLog("删除首页管理-党史学习教育表")
    @PostMapping("/homePage/hmpartyhistoryedu/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizHmPartyHistoryEduIdParam> bizHmPartyHistoryEduIdParamList) {
        bizHmPartyHistoryEduService.delete(bizHmPartyHistoryEduIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取首页管理-党史学习教育表详情
     *
     * @author shine
     * @date  2024/05/20 19:35
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取首页管理-党史学习教育表详情")
    @GetMapping("/homePage/hmpartyhistoryedu/detail")
    public CommonResult<BizHmPartyHistoryEdu> detail(@Valid BizHmPartyHistoryEduIdParam bizHmPartyHistoryEduIdParam) {
        return CommonResult.data(bizHmPartyHistoryEduService.detail(bizHmPartyHistoryEduIdParam));
    }


    @ApiOperationSupport(order = 6)
    @ApiOperation("*轮播信息管理")
    @GetMapping("/homePage/hmpartyhistoryedu/findPage")
    public CommonResult<IPage<Map<String,Object>>> findPage(BizHmPartyHistoryEduPageParam bizHmPartyHistoryEduPageParam) {
        return CommonResult.data(bizHmPartyHistoryEduService.findPage(bizHmPartyHistoryEduPageParam));
    }

    @ApiOperationSupport(order = 7)
    @ApiOperation("*批量启用、禁用")
    @PostMapping("/homePage/hmpartyhistoryedu/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizHmPartyHistoryEdu> list) {
        bizHmPartyHistoryEduService.batchUpdateStatus(list);
        return CommonResult.ok();
    }
}
