/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmpartyhistoryedu.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import com.unis.homePage.modular.hmcarouselconfig.entity.BizHmCarouselConfig;
import com.unis.homePage.modular.hmcarouselconfig.mapper.BizHmCarouselConfigMapper;
import com.unis.homePage.modular.hmcarouselconfig.param.BizHmCarouselConfigPageParam;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmpartyhistoryedu.entity.BizHmPartyHistoryEdu;
import com.unis.homePage.modular.hmpartyhistoryedu.mapper.BizHmPartyHistoryEduMapper;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduAddParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduEditParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduIdParam;
import com.unis.homePage.modular.hmpartyhistoryedu.param.BizHmPartyHistoryEduPageParam;
import com.unis.homePage.modular.hmpartyhistoryedu.service.BizHmPartyHistoryEduService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-党史学习教育表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:35
 **/
@Service
public class BizHmPartyHistoryEduServiceImpl extends ServiceImpl<BizHmPartyHistoryEduMapper, BizHmPartyHistoryEdu> implements BizHmPartyHistoryEduService {

    @Resource
    private BizHmPartyHistoryEduMapper bizHmPartyHistoryEduMapper;
    @Resource
    private BizHmCarouselConfigMapper bizHmCarouselConfigMapper;

    @Override
    public Page<BizHmPartyHistoryEdu> page(BizHmPartyHistoryEduPageParam bizHmPartyHistoryEduPageParam) {
        QueryWrapper<BizHmPartyHistoryEdu> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmPartyHistoryEduPageParam.getTitle())) {
            queryWrapper.lambda().like(BizHmPartyHistoryEdu::getTitle, bizHmPartyHistoryEduPageParam.getTitle());
        }
        if(ObjectUtil.isNotEmpty(bizHmPartyHistoryEduPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizHmPartyHistoryEdu::getStatus, bizHmPartyHistoryEduPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmPartyHistoryEduPageParam.getSortField(), bizHmPartyHistoryEduPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmPartyHistoryEduPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmPartyHistoryEduPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmPartyHistoryEduPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmPartyHistoryEdu::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmPartyHistoryEduAddParam bizHmPartyHistoryEduAddParam) {
        BizHmPartyHistoryEdu bizHmPartyHistoryEdu = BeanUtil.toBean(bizHmPartyHistoryEduAddParam, BizHmPartyHistoryEdu.class);
        this.save(bizHmPartyHistoryEdu);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmPartyHistoryEduEditParam bizHmPartyHistoryEduEditParam) {
        BizHmPartyHistoryEdu bizHmPartyHistoryEdu = this.queryEntity(bizHmPartyHistoryEduEditParam.getId());
        BeanUtil.copyProperties(bizHmPartyHistoryEduEditParam, bizHmPartyHistoryEdu);
        this.updateById(bizHmPartyHistoryEdu);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmPartyHistoryEduIdParam> bizHmPartyHistoryEduIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmPartyHistoryEduIdParamList, BizHmPartyHistoryEduIdParam::getId));
    }

    @Override
    public BizHmPartyHistoryEdu detail(BizHmPartyHistoryEduIdParam bizHmPartyHistoryEduIdParam) {
        return this.queryEntity(bizHmPartyHistoryEduIdParam.getId());
    }

    @Override
    public BizHmPartyHistoryEdu queryEntity(String id) {
        BizHmPartyHistoryEdu bizHmPartyHistoryEdu = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmPartyHistoryEdu)) {
            throw new CommonException("首页管理-党史学习教育表不存在，id值为：{}", id);
        }
        return bizHmPartyHistoryEdu;
    }

    @Override
    public IPage<Map<String, Object>> findPage(BizHmPartyHistoryEduPageParam bizHmPartyHistoryEduPageParam) {
        QueryWrapper<BizHmPartyHistoryEdu> queryWrapper = new QueryWrapper<>();
        //分页相关
        if (bizHmPartyHistoryEduPageParam.getStatus() != null) {
            queryWrapper.eq("status", bizHmPartyHistoryEduPageParam.getStatus());
        }
        if (bizHmPartyHistoryEduPageParam.getTitle() != null) {
            queryWrapper.like("title", bizHmPartyHistoryEduPageParam.getTitle());
        }

        Page<BizHmPartyHistoryEdu> p = new Page<>(bizHmPartyHistoryEduPageParam.getCurrent(), bizHmPartyHistoryEduPageParam.getSize());

        IPage<Map<String, Object>> page = bizHmPartyHistoryEduMapper.findPage(p, queryWrapper);
        return page;
    }

    @Override
    public void batchUpdateStatus(List<BizHmPartyHistoryEdu> list) {
        for(BizHmPartyHistoryEdu bizHmPartyHistoryEdu:list){
            if(bizHmPartyHistoryEdu.getType().equals(1)){//状态，1党史教育 2轮播图配置
                this.updateById(bizHmPartyHistoryEdu);
            }else if(bizHmPartyHistoryEdu.getType().equals(2)){
                BizHmCarouselConfig bizHmCarouselConfig = new BizHmCarouselConfig();
                bizHmCarouselConfig.setId(bizHmPartyHistoryEdu.getId());
                bizHmCarouselConfig.setStatus(bizHmPartyHistoryEdu.getStatus());
                bizHmCarouselConfigMapper.updateById(bizHmCarouselConfig);
            }

        }
    }


}
