/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmrelatedwebsitesconfig.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.homePage.modular.hmcarousel.entity.BizHmCarousel;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.entity.BizHmRelatedWebsitesConfig;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigAddParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigEditParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigIdParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigPageParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.service.BizHmRelatedWebsitesConfigService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 首页管理-相关网站模块配置表控制器
 *
 * @author shine
 * @date  2024/05/20 19:36
 */
@Api(tags = "首页管理-相关网站模块配置表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizHmRelatedWebsitesConfigController {

    @Resource
    private BizHmRelatedWebsitesConfigService bizHmRelatedWebsitesConfigService;

    /**
     * 获取首页管理-相关网站模块配置表分页
     *
     * @author shine
     * @date  2024/05/20 19:36
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取首页管理-相关网站模块配置表分页")
    @GetMapping("/homePage/hmrelatedwebsitesconfig/page")
    public CommonResult<Page<BizHmRelatedWebsitesConfig>> page(BizHmRelatedWebsitesConfigPageParam bizHmRelatedWebsitesConfigPageParam) {
        return CommonResult.data(bizHmRelatedWebsitesConfigService.page(bizHmRelatedWebsitesConfigPageParam));
    }

    /**
     * 添加首页管理-相关网站模块配置表
     *
     * @author shine
     * @date  2024/05/20 19:36
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加首页管理-相关网站模块配置表")
    @CommonLog("添加首页管理-相关网站模块配置表")
    @PostMapping("/homePage/hmrelatedwebsitesconfig/add")
    public CommonResult<String> add(@RequestBody @Valid BizHmRelatedWebsitesConfigAddParam bizHmRelatedWebsitesConfigAddParam) {
        bizHmRelatedWebsitesConfigService.add(bizHmRelatedWebsitesConfigAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑首页管理-相关网站模块配置表
     *
     * @author shine
     * @date  2024/05/20 19:36
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑首页管理-相关网站模块配置表")
    @CommonLog("编辑首页管理-相关网站模块配置表")
    @PostMapping("/homePage/hmrelatedwebsitesconfig/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizHmRelatedWebsitesConfigEditParam bizHmRelatedWebsitesConfigEditParam) {
        bizHmRelatedWebsitesConfigService.edit(bizHmRelatedWebsitesConfigEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除首页管理-相关网站模块配置表
     *
     * @author shine
     * @date  2024/05/20 19:36
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除首页管理-相关网站模块配置表")
    @CommonLog("删除首页管理-相关网站模块配置表")
    @PostMapping("/homePage/hmrelatedwebsitesconfig/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizHmRelatedWebsitesConfigIdParam> bizHmRelatedWebsitesConfigIdParamList) {
        bizHmRelatedWebsitesConfigService.delete(bizHmRelatedWebsitesConfigIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取首页管理-相关网站模块配置表详情
     *
     * @author shine
     * @date  2024/05/20 19:36
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取首页管理-相关网站模块配置表详情")
    @GetMapping("/homePage/hmrelatedwebsitesconfig/detail")
    public CommonResult<BizHmRelatedWebsitesConfig> detail(@Valid BizHmRelatedWebsitesConfigIdParam bizHmRelatedWebsitesConfigIdParam) {
        return CommonResult.data(bizHmRelatedWebsitesConfigService.detail(bizHmRelatedWebsitesConfigIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/homePage/hmrelatedwebsitesconfig/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizHmRelatedWebsitesConfig> list) {
        bizHmRelatedWebsitesConfigService.batchUpdateStatus(list);
        return CommonResult.ok();
    }
}
