/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmrelatedwebsitesconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmimagenews.entity.BizHmImageNews;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.entity.BizHmRelatedWebsitesConfig;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.mapper.BizHmRelatedWebsitesConfigMapper;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigAddParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigEditParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigIdParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.param.BizHmRelatedWebsitesConfigPageParam;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.service.BizHmRelatedWebsitesConfigService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-相关网站模块配置表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:36
 **/
@Service
public class BizHmRelatedWebsitesConfigServiceImpl extends ServiceImpl<BizHmRelatedWebsitesConfigMapper, BizHmRelatedWebsitesConfig> implements BizHmRelatedWebsitesConfigService {

    @Resource
    private BizHmRelatedWebsitesConfigMapper bizHmRelatedWebsitesConfigMapper;
    @Override
    public Page<BizHmRelatedWebsitesConfig> page(BizHmRelatedWebsitesConfigPageParam bizHmRelatedWebsitesConfigPageParam) {
        QueryWrapper<BizHmRelatedWebsitesConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmRelatedWebsitesConfigPageParam.getModuleName())) {
            queryWrapper.lambda().like(BizHmRelatedWebsitesConfig::getModuleName, bizHmRelatedWebsitesConfigPageParam.getModuleName());
        }
        if(ObjectUtil.isNotEmpty(bizHmRelatedWebsitesConfigPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizHmRelatedWebsitesConfig::getStatus, bizHmRelatedWebsitesConfigPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmRelatedWebsitesConfigPageParam.getSortField(), bizHmRelatedWebsitesConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmRelatedWebsitesConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmRelatedWebsitesConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmRelatedWebsitesConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmRelatedWebsitesConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmRelatedWebsitesConfigAddParam bizHmRelatedWebsitesConfigAddParam) {
        BizHmRelatedWebsitesConfig bizHmRelatedWebsitesConfig = BeanUtil.toBean(bizHmRelatedWebsitesConfigAddParam, BizHmRelatedWebsitesConfig.class);
        this.save(bizHmRelatedWebsitesConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmRelatedWebsitesConfigEditParam bizHmRelatedWebsitesConfigEditParam) {
        BizHmRelatedWebsitesConfig bizHmRelatedWebsitesConfig = this.queryEntity(bizHmRelatedWebsitesConfigEditParam.getId());
        BeanUtil.copyProperties(bizHmRelatedWebsitesConfigEditParam, bizHmRelatedWebsitesConfig);
        this.updateById(bizHmRelatedWebsitesConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmRelatedWebsitesConfigIdParam> bizHmRelatedWebsitesConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmRelatedWebsitesConfigIdParamList, BizHmRelatedWebsitesConfigIdParam::getId));
    }

    @Override
    public BizHmRelatedWebsitesConfig detail(BizHmRelatedWebsitesConfigIdParam bizHmRelatedWebsitesConfigIdParam) {
        return this.queryEntity(bizHmRelatedWebsitesConfigIdParam.getId());
    }

    @Override
    public BizHmRelatedWebsitesConfig queryEntity(String id) {
        BizHmRelatedWebsitesConfig bizHmRelatedWebsitesConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmRelatedWebsitesConfig)) {
            throw new CommonException("首页管理-相关网站模块配置表不存在，id值为：{}", id);
        }
        return bizHmRelatedWebsitesConfig;
    }

    @Override
    public void batchUpdateStatus(List<BizHmRelatedWebsitesConfig> list) {
        for(BizHmRelatedWebsitesConfig bizHmRelatedWebsitesConfig:list){
            this.updateById(bizHmRelatedWebsitesConfig);
        }
    }
}
