/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.hmsupervisioninspectionconfig.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmrelatedwebsitesconfig.entity.BizHmRelatedWebsitesConfig;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.entity.BizHmSupervisionInspectionConfig;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.mapper.BizHmSupervisionInspectionConfigMapper;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.param.BizHmSupervisionInspectionConfigAddParam;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.param.BizHmSupervisionInspectionConfigEditParam;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.param.BizHmSupervisionInspectionConfigIdParam;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.param.BizHmSupervisionInspectionConfigPageParam;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.service.BizHmSupervisionInspectionConfigService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 首页管理-监督检查模块配置表Service接口实现类
 *
 * @author shine
 * @date  2024/05/20 19:36
 **/
@Service
public class BizHmSupervisionInspectionConfigServiceImpl extends ServiceImpl<BizHmSupervisionInspectionConfigMapper, BizHmSupervisionInspectionConfig> implements BizHmSupervisionInspectionConfigService {

    @Resource
    private BizHmSupervisionInspectionConfigMapper bizHmSupervisionInspectionConfigMapper;
    @Override
    public Page<BizHmSupervisionInspectionConfig> page(BizHmSupervisionInspectionConfigPageParam bizHmSupervisionInspectionConfigPageParam) {
        QueryWrapper<BizHmSupervisionInspectionConfig> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizHmSupervisionInspectionConfigPageParam.getFunctionName())) {
            queryWrapper.lambda().like(BizHmSupervisionInspectionConfig::getFunctionName, bizHmSupervisionInspectionConfigPageParam.getFunctionName());
        }
        if(ObjectUtil.isNotEmpty(bizHmSupervisionInspectionConfigPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizHmSupervisionInspectionConfig::getStatus, bizHmSupervisionInspectionConfigPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizHmSupervisionInspectionConfigPageParam.getSortField(), bizHmSupervisionInspectionConfigPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizHmSupervisionInspectionConfigPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizHmSupervisionInspectionConfigPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizHmSupervisionInspectionConfigPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizHmSupervisionInspectionConfig::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizHmSupervisionInspectionConfigAddParam bizHmSupervisionInspectionConfigAddParam) {
        BizHmSupervisionInspectionConfig bizHmSupervisionInspectionConfig = BeanUtil.toBean(bizHmSupervisionInspectionConfigAddParam, BizHmSupervisionInspectionConfig.class);
        this.save(bizHmSupervisionInspectionConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizHmSupervisionInspectionConfigEditParam bizHmSupervisionInspectionConfigEditParam) {
        BizHmSupervisionInspectionConfig bizHmSupervisionInspectionConfig = this.queryEntity(bizHmSupervisionInspectionConfigEditParam.getId());
        BeanUtil.copyProperties(bizHmSupervisionInspectionConfigEditParam, bizHmSupervisionInspectionConfig);
        this.updateById(bizHmSupervisionInspectionConfig);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizHmSupervisionInspectionConfigIdParam> bizHmSupervisionInspectionConfigIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizHmSupervisionInspectionConfigIdParamList, BizHmSupervisionInspectionConfigIdParam::getId));
    }

    @Override
    public BizHmSupervisionInspectionConfig detail(BizHmSupervisionInspectionConfigIdParam bizHmSupervisionInspectionConfigIdParam) {
        return this.queryEntity(bizHmSupervisionInspectionConfigIdParam.getId());
    }

    @Override
    public BizHmSupervisionInspectionConfig queryEntity(String id) {
        BizHmSupervisionInspectionConfig bizHmSupervisionInspectionConfig = this.getById(id);
        if(ObjectUtil.isEmpty(bizHmSupervisionInspectionConfig)) {
            throw new CommonException("首页管理-监督检查模块配置表不存在，id值为：{}", id);
        }
        return bizHmSupervisionInspectionConfig;
    }

    @Override
    public void batchUpdateStatus(List<BizHmSupervisionInspectionConfig> list) {

        for(BizHmSupervisionInspectionConfig bizHmSupervisionInspectionConfig:list){
            this.updateById(bizHmSupervisionInspectionConfig);
        }
    }
}
