/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.pbcontrol.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.homePage.modular.pbcontrol.entity.BizPbControl;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlAddParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlEditParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlIdParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlPageParam;
import com.unis.homePage.modular.pbcontrol.service.BizPbControlService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 门户背景控制控制器
 *
 * @author shine
 * @date  2024/06/03 10:47
 */
@Api(tags = "门户背景控制控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizPbControlController {

    @Resource
    private BizPbControlService bizPbControlService;

    /**
     * 获取门户背景控制分页
     *
     * @author shine
     * @date  2024/06/03 10:47
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取门户背景控制分页")
    @GetMapping("/homePage/pbcontrol/page")
    public CommonResult<Page<BizPbControl>> page(BizPbControlPageParam bizPbControlPageParam) {
        return CommonResult.data(bizPbControlService.page(bizPbControlPageParam));
    }

    /**
     * 添加门户背景控制
     *
     * @author shine
     * @date  2024/06/03 10:47
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加门户背景控制")
    @PostMapping("/homePage/pbcontrol/add")
    public CommonResult<String> add(@RequestBody @Valid BizPbControlAddParam bizPbControlAddParam) {
        bizPbControlService.add(bizPbControlAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑门户背景控制
     *
     * @author shine
     * @date  2024/06/03 10:47
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑门户背景控制")
    @PostMapping("/homePage/pbcontrol/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizPbControlEditParam bizPbControlEditParam) {
        bizPbControlService.edit(bizPbControlEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除门户背景控制
     *
     * @author shine
     * @date  2024/06/03 10:47
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除门户背景控制")
    @PostMapping("/homePage/pbcontrol/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizPbControlIdParam> bizPbControlIdParamList) {
        bizPbControlService.delete(bizPbControlIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取门户背景控制详情
     *
     * @author shine
     * @date  2024/06/03 10:47
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取门户背景控制详情")
    @GetMapping("/homePage/pbcontrol/detail")
    public CommonResult<BizPbControl> detail(@Valid BizPbControlIdParam bizPbControlIdParam) {
        return CommonResult.data(bizPbControlService.detail(bizPbControlIdParam));
    }
}
