/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.homePage.modular.pbcontrol.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.homePage.modular.pbcontrol.entity.BizPbControl;
import com.unis.homePage.modular.pbcontrol.mapper.BizPbControlMapper;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlAddParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlEditParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlIdParam;
import com.unis.homePage.modular.pbcontrol.param.BizPbControlPageParam;
import com.unis.homePage.modular.pbcontrol.service.BizPbControlService;

import java.util.List;

/**
 * 门户背景控制Service接口实现类
 *
 * @author shine
 * @date  2024/06/03 10:47
 **/
@Service
public class BizPbControlServiceImpl extends ServiceImpl<BizPbControlMapper, BizPbControl> implements BizPbControlService {

    @Override
    public Page<BizPbControl> page(BizPbControlPageParam bizPbControlPageParam) {
        QueryWrapper<BizPbControl> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizPbControlPageParam.getMourningDaySwitch())) {
            queryWrapper.lambda().eq(BizPbControl::getMourningDaySwitch, bizPbControlPageParam.getMourningDaySwitch());
        }
        if(ObjectUtil.isAllNotEmpty(bizPbControlPageParam.getSortField(), bizPbControlPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizPbControlPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizPbControlPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizPbControlPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizPbControl::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizPbControlAddParam bizPbControlAddParam) {
        BizPbControl bizPbControl = BeanUtil.toBean(bizPbControlAddParam, BizPbControl.class);
        this.save(bizPbControl);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizPbControlEditParam bizPbControlEditParam) {
        BizPbControl bizPbControl = this.queryEntity(bizPbControlEditParam.getId());
        BeanUtil.copyProperties(bizPbControlEditParam, bizPbControl);
        this.updateById(bizPbControl);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizPbControlIdParam> bizPbControlIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizPbControlIdParamList, BizPbControlIdParam::getId));
    }

    @Override
    public BizPbControl detail(BizPbControlIdParam bizPbControlIdParam) {
        return this.queryEntity(bizPbControlIdParam.getId());
    }

    @Override
    public BizPbControl queryEntity(String id) {
        BizPbControl bizPbControl = this.getById(id);
        if(ObjectUtil.isEmpty(bizPbControl)) {
            throw new CommonException("门户背景控制不存在，id值为：{}", id);
        }
        return bizPbControl;
    }
}
