/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.singrainbureaunotice.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.util.OrderNumberUtil;
import com.unis.homePage.modular.hmsupervisioninspectionconfig.entity.BizHmSupervisionInspectionConfig;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.importantNews.modular.singrainbureaunotice.entity.BizSinGrainBureauNotice;
import com.unis.importantNews.modular.singrainbureaunotice.mapper.BizSinGrainBureauNoticeMapper;
import com.unis.importantNews.modular.singrainbureaunotice.param.BizSinGrainBureauNoticeAddParam;
import com.unis.importantNews.modular.singrainbureaunotice.param.BizSinGrainBureauNoticeEditParam;
import com.unis.importantNews.modular.singrainbureaunotice.param.BizSinGrainBureauNoticeIdParam;
import com.unis.importantNews.modular.singrainbureaunotice.param.BizSinGrainBureauNoticePageParam;
import com.unis.importantNews.modular.singrainbureaunotice.service.BizSinGrainBureauNoticeService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 要闻概况-粮食局公告管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/21 15:32
 **/
@Service
public class BizSinGrainBureauNoticeServiceImpl extends ServiceImpl<BizSinGrainBureauNoticeMapper, BizSinGrainBureauNotice> implements BizSinGrainBureauNoticeService {

    @Resource
    private BizSinGrainBureauNoticeMapper bizSinGrainBureauNoticeMapper;
    @Override
    public Page<BizSinGrainBureauNotice> page(BizSinGrainBureauNoticePageParam bizSinGrainBureauNoticePageParam) {
        QueryWrapper<BizSinGrainBureauNotice> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSinGrainBureauNoticePageParam.getTitle())) {
            queryWrapper.lambda().like(BizSinGrainBureauNotice::getTitle, bizSinGrainBureauNoticePageParam.getTitle());
        }
        if(ObjectUtil.isNotEmpty(bizSinGrainBureauNoticePageParam.getIsValid())) {
            queryWrapper.lambda().eq(BizSinGrainBureauNotice::getIsValid, bizSinGrainBureauNoticePageParam.getIsValid());
        }
        if(ObjectUtil.isNotEmpty(bizSinGrainBureauNoticePageParam.getNoticeContent())) {
            queryWrapper.lambda().like(BizSinGrainBureauNotice::getNoticeContent, bizSinGrainBureauNoticePageParam.getNoticeContent());
        }
        if(ObjectUtil.isNotEmpty(bizSinGrainBureauNoticePageParam.getStatus())) {
            queryWrapper.lambda().eq(BizSinGrainBureauNotice::getStatus, bizSinGrainBureauNoticePageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizSinGrainBureauNoticePageParam.getSortField(), bizSinGrainBureauNoticePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSinGrainBureauNoticePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSinGrainBureauNoticePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSinGrainBureauNoticePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSinGrainBureauNotice::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSinGrainBureauNoticeAddParam bizSinGrainBureauNoticeAddParam) {
        BizSinGrainBureauNotice bizSinGrainBureauNotice = BeanUtil.toBean(bizSinGrainBureauNoticeAddParam, BizSinGrainBureauNotice.class);
        this.save(bizSinGrainBureauNotice);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSinGrainBureauNoticeEditParam bizSinGrainBureauNoticeEditParam) {
        BizSinGrainBureauNotice bizSinGrainBureauNotice = this.queryEntity(bizSinGrainBureauNoticeEditParam.getId());
        BeanUtil.copyProperties(bizSinGrainBureauNoticeEditParam, bizSinGrainBureauNotice);
        this.updateById(bizSinGrainBureauNotice);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSinGrainBureauNoticeIdParam> bizSinGrainBureauNoticeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSinGrainBureauNoticeIdParamList, BizSinGrainBureauNoticeIdParam::getId));
    }

    @Override
    public BizSinGrainBureauNotice detail(BizSinGrainBureauNoticeIdParam bizSinGrainBureauNoticeIdParam) {
        return this.queryEntity(bizSinGrainBureauNoticeIdParam.getId());
    }

    @Override
    public BizSinGrainBureauNotice queryEntity(String id) {
        BizSinGrainBureauNotice bizSinGrainBureauNotice = this.getById(id);
        if(ObjectUtil.isEmpty(bizSinGrainBureauNotice)) {
            throw new CommonException("要闻概况-粮食局公告管理表不存在，id值为：{}", id);
        }
        return bizSinGrainBureauNotice;
    }

    @Override
    public void batchUpdateStatus(List<BizSinGrainBureauNotice> list) {

        for(BizSinGrainBureauNotice bizSinGrainBureauNotice:list){
            this.updateById(bizSinGrainBureauNotice);
        }
    }

    @Override
    public IPage<Map<String, Object>> search(BizSinGrainBureauNoticePageParam bizSinGrainBureauNoticePageParam) {
        QueryWrapper<BizSinGrainBureauNotice> queryWrapper = new QueryWrapper<>();


        Page<BizSinGrainBureauNotice> p = new Page<>(bizSinGrainBureauNoticePageParam.getCurrent(), bizSinGrainBureauNoticePageParam.getSize());

        IPage<Map<String, Object>> page = bizSinGrainBureauNoticeMapper.findPage(p, bizSinGrainBureauNoticePageParam.getTitle());
        return page;
    }

    @Override
    public String getIndexNumber() {
        QueryWrapper<BizSinGrainBureauNotice> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().orderByDesc(BizSinGrainBureauNotice::getIndexNumber);
        List<BizSinGrainBureauNotice> list= this.list(queryWrapper);
        if(list.size()>0){
            return OrderNumberUtil.indexNumber("01284/",5,list.get(0).getIndexNumber());
        }else{
            return OrderNumberUtil.indexNumber("01284/",5,"");
        }
    }
}
