/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.sinnoticeannouncement.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.importantNews.modular.singrainbureaunotice.entity.BizSinGrainBureauNotice;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.importantNews.modular.sinnoticeannouncement.entity.BizSinNoticeAnnouncement;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementAddParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementEditParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementIdParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementPageParam;
import com.unis.importantNews.modular.sinnoticeannouncement.service.BizSinNoticeAnnouncementService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 要闻概况-通知公告管理表控制器
 *
 * @author shine
 * @date  2024/05/21 15:33
 */
@Api(tags = "要闻概况-通知公告管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizSinNoticeAnnouncementController {

    @Resource
    private BizSinNoticeAnnouncementService bizSinNoticeAnnouncementService;

    /**
     * 获取要闻概况-通知公告管理表分页
     *
     * @author shine
     * @date  2024/05/21 15:33
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取要闻概况-通知公告管理表分页")
    @GetMapping("/importantNews/sinnoticeannouncement/page")
    public CommonResult<Page<BizSinNoticeAnnouncement>> page(BizSinNoticeAnnouncementPageParam bizSinNoticeAnnouncementPageParam) {
        return CommonResult.data(bizSinNoticeAnnouncementService.page(bizSinNoticeAnnouncementPageParam));
    }

    /**
     * 添加要闻概况-通知公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:33
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加要闻概况-通知公告管理表")
    @CommonLog("添加要闻概况-通知公告管理表")
    @PostMapping("/importantNews/sinnoticeannouncement/add")
    public CommonResult<String> add(@RequestBody @Valid BizSinNoticeAnnouncementAddParam bizSinNoticeAnnouncementAddParam) {
        bizSinNoticeAnnouncementService.add(bizSinNoticeAnnouncementAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑要闻概况-通知公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:33
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑要闻概况-通知公告管理表")
    @CommonLog("编辑要闻概况-通知公告管理表")
    @PostMapping("/importantNews/sinnoticeannouncement/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSinNoticeAnnouncementEditParam bizSinNoticeAnnouncementEditParam) {
        bizSinNoticeAnnouncementService.edit(bizSinNoticeAnnouncementEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除要闻概况-通知公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:33
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除要闻概况-通知公告管理表")
    @CommonLog("删除要闻概况-通知公告管理表")
    @PostMapping("/importantNews/sinnoticeannouncement/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizSinNoticeAnnouncementIdParam> bizSinNoticeAnnouncementIdParamList) {
        bizSinNoticeAnnouncementService.delete(bizSinNoticeAnnouncementIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取要闻概况-通知公告管理表详情
     *
     * @author shine
     * @date  2024/05/21 15:33
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取要闻概况-通知公告管理表详情")
    @GetMapping("/importantNews/sinnoticeannouncement/detail")
    public CommonResult<BizSinNoticeAnnouncement> detail(@Valid BizSinNoticeAnnouncementIdParam bizSinNoticeAnnouncementIdParam) {
        return CommonResult.data(bizSinNoticeAnnouncementService.detail(bizSinNoticeAnnouncementIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/importantNews/sinnoticeannouncement/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizSinNoticeAnnouncement> list) {
        bizSinNoticeAnnouncementService.batchUpdateStatus(list);
        return CommonResult.ok();
    }
}
