/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.sinnoticeannouncement.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.importantNews.modular.singrainbureaunotice.entity.BizSinGrainBureauNotice;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.importantNews.modular.sinnoticeannouncement.entity.BizSinNoticeAnnouncement;
import com.unis.importantNews.modular.sinnoticeannouncement.mapper.BizSinNoticeAnnouncementMapper;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementAddParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementEditParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementIdParam;
import com.unis.importantNews.modular.sinnoticeannouncement.param.BizSinNoticeAnnouncementPageParam;
import com.unis.importantNews.modular.sinnoticeannouncement.service.BizSinNoticeAnnouncementService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 要闻概况-通知公告管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/21 15:33
 **/
@Service
public class BizSinNoticeAnnouncementServiceImpl extends ServiceImpl<BizSinNoticeAnnouncementMapper, BizSinNoticeAnnouncement> implements BizSinNoticeAnnouncementService {

    @Resource
    private BizSinNoticeAnnouncementMapper bizSinNoticeAnnouncementMapper;

    @Override
    public Page<BizSinNoticeAnnouncement> page(BizSinNoticeAnnouncementPageParam bizSinNoticeAnnouncementPageParam) {
        QueryWrapper<BizSinNoticeAnnouncement> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSinNoticeAnnouncementPageParam.getTitle())) {
            queryWrapper.lambda().like(BizSinNoticeAnnouncement::getTitle, bizSinNoticeAnnouncementPageParam.getTitle());
        }
        if(ObjectUtil.isNotEmpty(bizSinNoticeAnnouncementPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizSinNoticeAnnouncement::getStatus, bizSinNoticeAnnouncementPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizSinNoticeAnnouncementPageParam.getSortField(), bizSinNoticeAnnouncementPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSinNoticeAnnouncementPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSinNoticeAnnouncementPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSinNoticeAnnouncementPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSinNoticeAnnouncement::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSinNoticeAnnouncementAddParam bizSinNoticeAnnouncementAddParam) {
        BizSinNoticeAnnouncement bizSinNoticeAnnouncement = BeanUtil.toBean(bizSinNoticeAnnouncementAddParam, BizSinNoticeAnnouncement.class);
        this.save(bizSinNoticeAnnouncement);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSinNoticeAnnouncementEditParam bizSinNoticeAnnouncementEditParam) {
        BizSinNoticeAnnouncement bizSinNoticeAnnouncement = this.queryEntity(bizSinNoticeAnnouncementEditParam.getId());
        BeanUtil.copyProperties(bizSinNoticeAnnouncementEditParam, bizSinNoticeAnnouncement);
        this.updateById(bizSinNoticeAnnouncement);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSinNoticeAnnouncementIdParam> bizSinNoticeAnnouncementIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSinNoticeAnnouncementIdParamList, BizSinNoticeAnnouncementIdParam::getId));
    }

    @Override
    public BizSinNoticeAnnouncement detail(BizSinNoticeAnnouncementIdParam bizSinNoticeAnnouncementIdParam) {
        return this.queryEntity(bizSinNoticeAnnouncementIdParam.getId());
    }

    @Override
    public BizSinNoticeAnnouncement queryEntity(String id) {
        BizSinNoticeAnnouncement bizSinNoticeAnnouncement = this.getById(id);
        if(ObjectUtil.isEmpty(bizSinNoticeAnnouncement)) {
            throw new CommonException("要闻概况-通知公告管理表不存在，id值为：{}", id);
        }
        return bizSinNoticeAnnouncement;
    }

    @Override
    public void batchUpdateStatus(List<BizSinNoticeAnnouncement> list) {

        for(BizSinNoticeAnnouncement bizSinNoticeAnnouncement:list){
            this.updateById(bizSinNoticeAnnouncement);
        }

    }
}
