/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.sinqinghainews.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.importantNews.modular.sinnoticeannouncement.entity.BizSinNoticeAnnouncement;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.importantNews.modular.sinqinghainews.entity.BizSinQinghaiNews;
import com.unis.importantNews.modular.sinqinghainews.mapper.BizSinQinghaiNewsMapper;
import com.unis.importantNews.modular.sinqinghainews.param.BizSinQinghaiNewsAddParam;
import com.unis.importantNews.modular.sinqinghainews.param.BizSinQinghaiNewsEditParam;
import com.unis.importantNews.modular.sinqinghainews.param.BizSinQinghaiNewsIdParam;
import com.unis.importantNews.modular.sinqinghainews.param.BizSinQinghaiNewsPageParam;
import com.unis.importantNews.modular.sinqinghainews.service.BizSinQinghaiNewsService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 要闻概况-青海要闻管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/21 15:34
 **/
@Service
public class BizSinQinghaiNewsServiceImpl extends ServiceImpl<BizSinQinghaiNewsMapper, BizSinQinghaiNews> implements BizSinQinghaiNewsService {

    @Resource
    private BizSinQinghaiNewsMapper bizSinQinghaiNewsMapper;
    @Override
    public Page<BizSinQinghaiNews> page(BizSinQinghaiNewsPageParam bizSinQinghaiNewsPageParam) {
        QueryWrapper<BizSinQinghaiNews> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSinQinghaiNewsPageParam.getTitle())) {
            queryWrapper.lambda().like(BizSinQinghaiNews::getTitle, bizSinQinghaiNewsPageParam.getTitle());
        }
        if(ObjectUtil.isNotEmpty(bizSinQinghaiNewsPageParam.getIsRedirect())) {
            queryWrapper.lambda().eq(BizSinQinghaiNews::getIsRedirect, bizSinQinghaiNewsPageParam.getIsRedirect());
        }
        if(ObjectUtil.isNotEmpty(bizSinQinghaiNewsPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizSinQinghaiNews::getStatus, bizSinQinghaiNewsPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizSinQinghaiNewsPageParam.getSortField(), bizSinQinghaiNewsPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSinQinghaiNewsPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSinQinghaiNewsPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSinQinghaiNewsPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSinQinghaiNews::getPublishDate);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSinQinghaiNewsAddParam bizSinQinghaiNewsAddParam) {
        BizSinQinghaiNews bizSinQinghaiNews = BeanUtil.toBean(bizSinQinghaiNewsAddParam, BizSinQinghaiNews.class);
        this.save(bizSinQinghaiNews);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSinQinghaiNewsEditParam bizSinQinghaiNewsEditParam) {
        BizSinQinghaiNews bizSinQinghaiNews = this.queryEntity(bizSinQinghaiNewsEditParam.getId());
        BeanUtil.copyProperties(bizSinQinghaiNewsEditParam, bizSinQinghaiNews);
        this.updateById(bizSinQinghaiNews);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSinQinghaiNewsIdParam> bizSinQinghaiNewsIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSinQinghaiNewsIdParamList, BizSinQinghaiNewsIdParam::getId));
    }

    @Override
    public BizSinQinghaiNews detail(BizSinQinghaiNewsIdParam bizSinQinghaiNewsIdParam) {
        return this.queryEntity(bizSinQinghaiNewsIdParam.getId());
    }

    @Override
    public BizSinQinghaiNews queryEntity(String id) {
        BizSinQinghaiNews bizSinQinghaiNews = this.getById(id);
        if(ObjectUtil.isEmpty(bizSinQinghaiNews)) {
            throw new CommonException("要闻概况-青海要闻管理表不存在，id值为：{}", id);
        }
        return bizSinQinghaiNews;
    }

    @Override
    public void batchUpdateStatus(List<BizSinQinghaiNews> list) {

        for(BizSinQinghaiNews bizSinQinghaiNews:list){
            this.updateById(bizSinQinghaiNews);
        }
    }
}
