/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.sinstatecouncilnotice.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.importantNews.modular.sinqinghainews.entity.BizSinQinghaiNews;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.importantNews.modular.sinstatecouncilnotice.entity.BizSinStateCouncilNotice;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeAddParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeEditParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeIdParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticePageParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.service.BizSinStateCouncilNoticeService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 要闻概况-国务院公告管理表控制器
 *
 * @author shine
 * @date  2024/05/21 15:35
 */
@Api(tags = "要闻概况-国务院公告管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizSinStateCouncilNoticeController {

    @Resource
    private BizSinStateCouncilNoticeService bizSinStateCouncilNoticeService;

    /**
     * 获取要闻概况-国务院公告管理表分页
     *
     * @author shine
     * @date  2024/05/21 15:35
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取要闻概况-国务院公告管理表分页")
    @GetMapping("/importantNews/sinstatecouncilnotice/page")
    public CommonResult<Page<BizSinStateCouncilNotice>> page(BizSinStateCouncilNoticePageParam bizSinStateCouncilNoticePageParam) {
        return CommonResult.data(bizSinStateCouncilNoticeService.page(bizSinStateCouncilNoticePageParam));
    }

    /**
     * 添加要闻概况-国务院公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:35
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加要闻概况-国务院公告管理表")
    @CommonLog("添加要闻概况-国务院公告管理表")
    @PostMapping("/importantNews/sinstatecouncilnotice/add")
    public CommonResult<String> add(@RequestBody @Valid BizSinStateCouncilNoticeAddParam bizSinStateCouncilNoticeAddParam) {
        bizSinStateCouncilNoticeService.add(bizSinStateCouncilNoticeAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑要闻概况-国务院公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:35
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑要闻概况-国务院公告管理表")
    @CommonLog("编辑要闻概况-国务院公告管理表")
    @PostMapping("/importantNews/sinstatecouncilnotice/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizSinStateCouncilNoticeEditParam bizSinStateCouncilNoticeEditParam) {
        bizSinStateCouncilNoticeService.edit(bizSinStateCouncilNoticeEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除要闻概况-国务院公告管理表
     *
     * @author shine
     * @date  2024/05/21 15:35
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除要闻概况-国务院公告管理表")
    @CommonLog("删除要闻概况-国务院公告管理表")
    @PostMapping("/importantNews/sinstatecouncilnotice/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizSinStateCouncilNoticeIdParam> bizSinStateCouncilNoticeIdParamList) {
        bizSinStateCouncilNoticeService.delete(bizSinStateCouncilNoticeIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取要闻概况-国务院公告管理表详情
     *
     * @author shine
     * @date  2024/05/21 15:35
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取要闻概况-国务院公告管理表详情")
    @GetMapping("/importantNews/sinstatecouncilnotice/detail")
    public CommonResult<BizSinStateCouncilNotice> detail(@Valid BizSinStateCouncilNoticeIdParam bizSinStateCouncilNoticeIdParam) {
        return CommonResult.data(bizSinStateCouncilNoticeService.detail(bizSinStateCouncilNoticeIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/importantNews/sinstatecouncilnotice/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizSinStateCouncilNotice> list) {
        bizSinStateCouncilNoticeService.batchUpdateStatus(list);
        return CommonResult.ok();
    }
}
