/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.importantNews.modular.sinstatecouncilnotice.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.importantNews.modular.sinqinghainews.entity.BizSinQinghaiNews;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.importantNews.modular.sinstatecouncilnotice.entity.BizSinStateCouncilNotice;
import com.unis.importantNews.modular.sinstatecouncilnotice.mapper.BizSinStateCouncilNoticeMapper;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeAddParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeEditParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticeIdParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.param.BizSinStateCouncilNoticePageParam;
import com.unis.importantNews.modular.sinstatecouncilnotice.service.BizSinStateCouncilNoticeService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 要闻概况-国务院公告管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/21 15:35
 **/
@Service
public class BizSinStateCouncilNoticeServiceImpl extends ServiceImpl<BizSinStateCouncilNoticeMapper, BizSinStateCouncilNotice> implements BizSinStateCouncilNoticeService {

    @Resource
    private BizSinStateCouncilNoticeMapper bizSinStateCouncilNoticeMapper;
    @Override
    public Page<BizSinStateCouncilNotice> page(BizSinStateCouncilNoticePageParam bizSinStateCouncilNoticePageParam) {
        QueryWrapper<BizSinStateCouncilNotice> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizSinStateCouncilNoticePageParam.getTitle())) {
            queryWrapper.lambda().like(BizSinStateCouncilNotice::getTitle, bizSinStateCouncilNoticePageParam.getTitle());
        }
        if(ObjectUtil.isNotEmpty(bizSinStateCouncilNoticePageParam.getIsRedirect())) {
            queryWrapper.lambda().eq(BizSinStateCouncilNotice::getIsRedirect, bizSinStateCouncilNoticePageParam.getIsRedirect());
        }
        if(ObjectUtil.isNotEmpty(bizSinStateCouncilNoticePageParam.getStatus())) {
            queryWrapper.lambda().eq(BizSinStateCouncilNotice::getStatus, bizSinStateCouncilNoticePageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizSinStateCouncilNoticePageParam.getSortField(), bizSinStateCouncilNoticePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizSinStateCouncilNoticePageParam.getSortOrder());
            queryWrapper.orderBy(true, bizSinStateCouncilNoticePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizSinStateCouncilNoticePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizSinStateCouncilNotice::getPublishDate);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizSinStateCouncilNoticeAddParam bizSinStateCouncilNoticeAddParam) {
        BizSinStateCouncilNotice bizSinStateCouncilNotice = BeanUtil.toBean(bizSinStateCouncilNoticeAddParam, BizSinStateCouncilNotice.class);
        this.save(bizSinStateCouncilNotice);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizSinStateCouncilNoticeEditParam bizSinStateCouncilNoticeEditParam) {
        BizSinStateCouncilNotice bizSinStateCouncilNotice = this.queryEntity(bizSinStateCouncilNoticeEditParam.getId());
        BeanUtil.copyProperties(bizSinStateCouncilNoticeEditParam, bizSinStateCouncilNotice);
        this.updateById(bizSinStateCouncilNotice);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizSinStateCouncilNoticeIdParam> bizSinStateCouncilNoticeIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizSinStateCouncilNoticeIdParamList, BizSinStateCouncilNoticeIdParam::getId));
    }

    @Override
    public BizSinStateCouncilNotice detail(BizSinStateCouncilNoticeIdParam bizSinStateCouncilNoticeIdParam) {
        return this.queryEntity(bizSinStateCouncilNoticeIdParam.getId());
    }

    @Override
    public BizSinStateCouncilNotice queryEntity(String id) {
        BizSinStateCouncilNotice bizSinStateCouncilNotice = this.getById(id);
        if(ObjectUtil.isEmpty(bizSinStateCouncilNotice)) {
            throw new CommonException("要闻概况-国务院公告管理表不存在，id值为：{}", id);
        }
        return bizSinStateCouncilNotice;
    }

    @Override
    public void batchUpdateStatus(List<BizSinStateCouncilNotice> list) {

        for(BizSinStateCouncilNotice bizSinStateCouncilNotice:list){
            this.updateById(bizSinStateCouncilNotice);
        }
    }
}
