/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.interactiveCommunication.modular.icLeaderMailbox.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.entity.IcLeaderMailbox;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.mapper.IcLeaderMailboxMapper;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.param.IcLeaderMailboxAddParam;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.param.IcLeaderMailboxEditParam;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.param.IcLeaderMailboxIdParam;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.param.IcLeaderMailboxPageParam;
import com.unis.interactiveCommunication.modular.icLeaderMailbox.service.IcLeaderMailboxService;

import java.util.Date;
import java.util.List;

/**
 * 互动交流-领导信箱表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/23 09:26
 **/
@Service
public class IcLeaderMailboxServiceImpl extends ServiceImpl<IcLeaderMailboxMapper, IcLeaderMailbox> implements IcLeaderMailboxService {

    @Override
    public Page<IcLeaderMailbox> page(IcLeaderMailboxPageParam icLeaderMailboxPageParam) {
        QueryWrapper<IcLeaderMailbox> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(icLeaderMailboxPageParam.getTitle())) {
            queryWrapper.like("title", icLeaderMailboxPageParam.getTitle());
        }
        if (ObjectUtil.isNotEmpty(icLeaderMailboxPageParam.getReplyStatus())) {
            queryWrapper.eq("audit_status", icLeaderMailboxPageParam.getReplyStatus());
        }
        if (ObjectUtil.isAllNotEmpty(icLeaderMailboxPageParam.getSortField(), icLeaderMailboxPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(icLeaderMailboxPageParam.getSortOrder());
            queryWrapper.orderBy(true, icLeaderMailboxPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(icLeaderMailboxPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(IcLeaderMailbox::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(IcLeaderMailboxAddParam icLeaderMailboxAddParam) {
        IcLeaderMailbox icLeaderMailbox = BeanUtil.toBean(icLeaderMailboxAddParam, IcLeaderMailbox.class);
        this.save(icLeaderMailbox);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(IcLeaderMailboxEditParam icLeaderMailboxEditParam) {
        IcLeaderMailbox icLeaderMailbox = this.queryEntity(icLeaderMailboxEditParam.getId());
        BeanUtil.copyProperties(icLeaderMailboxEditParam, icLeaderMailbox);
        icLeaderMailbox.setReplyTime(new Date());
        this.updateById(icLeaderMailbox);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<IcLeaderMailboxIdParam> icLeaderMailboxIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(icLeaderMailboxIdParamList, IcLeaderMailboxIdParam::getId));
    }

    @Override
    public IcLeaderMailbox detail(IcLeaderMailboxIdParam icLeaderMailboxIdParam) {
        return this.queryEntity(icLeaderMailboxIdParam.getId());
    }

    @Override
    public IcLeaderMailbox queryEntity(String id) {
        IcLeaderMailbox icLeaderMailbox = this.getById(id);
        if (ObjectUtil.isEmpty(icLeaderMailbox)) {
            throw new CommonException("互动交流-领导信箱表不存在，id值为：{}", id);
        }
        return icLeaderMailbox;
    }

    /**
     * 网站-一页展示5条数据
     *
     * @author hjc
     * @date 2024/05/23 09:26
     */
    @Override
    public Page<IcLeaderMailbox> getSitePage(IcLeaderMailboxPageParam icLeaderMailboxPageParam) {

        QueryWrapper<IcLeaderMailbox> queryWrapper = new QueryWrapper<>();

        queryWrapper.eq("reply_status", 1).eq("audit_status", 1);

        if (ObjectUtil.isAllNotEmpty(icLeaderMailboxPageParam.getSortField(), icLeaderMailboxPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(icLeaderMailboxPageParam.getSortOrder());
            queryWrapper.orderBy(true, icLeaderMailboxPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(icLeaderMailboxPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(IcLeaderMailbox::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);

    }
}
