/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.interactiveCommunication.modular.icPublicComplaint.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.interactiveCommunication.modular.icPublicComplaint.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.interactiveCommunication.modular.icPublicComplaint.entity.IcPublicComplaint;
import com.unis.interactiveCommunication.modular.icPublicComplaint.service.IcPublicComplaintService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 互动交流-信访举报表控制器
 *
 * @author hjc
 * @date  2024/05/24 14:40
 */
@Api(tags = "互动交流-信访举报表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class IcPublicComplaintController {

    @Resource
    private IcPublicComplaintService icPublicComplaintService;

    /**
     * 获取互动交流-信访举报表分页
     *
     * @author hjc
     * @date  2024/05/24 14:40
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取互动交流-信访举报表分页")
    //@SaCheckPermission("/interactiveCommunication/icPublicComplaint/page")
    @GetMapping("/interactiveCommunication/icPublicComplaint/page")
    public CommonResult<Page<IcPublicComplaint>> page(IcPublicComplaintPageParam icPublicComplaintPageParam) {
        return CommonResult.data(icPublicComplaintService.page(icPublicComplaintPageParam));
    }

    /**
     * 网站-添加信访举报
     *
     * @author hjc
     * @date  2024/05/24 14:40
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("网站-添加信访举报")
    @CommonLog("网站-添加信访举报")
   // @SaCheckPermission("/interactiveCommunication/icPublicComplaint/add")
    @PostMapping("/interactiveCommunication/icPublicComplaint/add")
    public CommonResult<String> add(@RequestBody @Valid IcPublicComplaintAddParam icPublicComplaintAddParam) {

        return CommonResult.data(icPublicComplaintService.add(icPublicComplaintAddParam));
    }

    /**
     * 网站-举报跟踪
     *
     * @author hjc
     * @date  2024/05/24 14:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站-举报跟踪")
    //@SaCheckPermission("/interactiveCommunication/icPublicComplaint/detail")
    @GetMapping("/interactiveCommunication/icPublicComplaint/reportTracking")
    public CommonResult<IcPublicComplaint> reportTracking(@Valid ComplaintNumberParam param) {
        return CommonResult.data(icPublicComplaintService.reportTracking(param));
    }


    /**
     * 管理端-回复
     *
     * @author hjc
     * @date  2024/05/24 14:40
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("管理端-回复")
    @CommonLog("管理端-回复")
   // @SaCheckPermission("/interactiveCommunication/icPublicComplaint/edit")
    @PostMapping("/interactiveCommunication/icPublicComplaint/edit")
    public CommonResult<String> edit(@RequestBody @Valid IcPublicComplaintEditParam icPublicComplaintEditParam) {
        icPublicComplaintService.edit(icPublicComplaintEditParam);
        return CommonResult.ok();
    }
/*
    *//**
     * 删除互动交流-信访举报表
     *
     * @author hjc
     * @date  2024/05/24 14:40
     *//*
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除互动交流-信访举报表")
    @CommonLog("删除互动交流-信访举报表")
    //@SaCheckPermission("/interactiveCommunication/icPublicComplaint/delete")
    @PostMapping("/interactiveCommunication/icPublicComplaint/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<IcPublicComplaintIdParam> icPublicComplaintIdParamList) {
        icPublicComplaintService.delete(icPublicComplaintIdParamList);
        return CommonResult.ok();
    }*/

    /**
     * 获取互动交流-信访举报表详情
     *
     * @author hjc
     * @date  2024/05/24 14:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取互动交流-信访举报表详情")
    //@SaCheckPermission("/interactiveCommunication/icPublicComplaint/detail")
    @GetMapping("/interactiveCommunication/icPublicComplaint/detail")
    public CommonResult<IcPublicComplaint> detail(@Valid IcPublicComplaintIdParam icPublicComplaintIdParam) {
        return CommonResult.data(icPublicComplaintService.detail(icPublicComplaintIdParam));
    }
}
