/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.interactiveCommunication.modular.icPublicOpinionCollect.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.param.*;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.vo.IcPublicOpinionCollectVO;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.param.IcPublicOpinionCollectMessageIdParam;
import com.unis.openGovernment.modular.ogAdministrativeDocument.param.OgAdministrativeDocumentAndStatusParam;
import com.unis.organization.modular.iodepartmentfunction.entity.BizIoDepartmentFunction;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.entity.IcPublicOpinionCollect;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.service.IcPublicOpinionCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 互动交流-民意征集管理表控制器
 *
 * @author hjc
 * @date 2024/05/23 19:44
 */
@Api(tags = "互动交流-民意征集管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class IcPublicOpinionCollectController {

    @Resource
    private IcPublicOpinionCollectService icPublicOpinionCollectService;

    /**
     * 获取互动交流-民意征集管理表分页
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取互动交流-民意征集管理表分页")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/page")
    @GetMapping("/interactiveCommunication/icPublicOpinionCollect/page")
    public CommonResult<Page<IcPublicOpinionCollectVO>> page(IcPublicOpinionCollectPageParam icPublicOpinionCollectPageParam) {
        return CommonResult.data(icPublicOpinionCollectService.page(icPublicOpinionCollectPageParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/interactiveCommunication/icPublicOpinionCollect/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgAdministrativeDocumentAndStatusParam> paramCommonValidList) {
        icPublicOpinionCollectService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }

    /**
     * 获取互动交流-民意征集管理表详情
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取互动交流-民意征集管理表详情")
    // @SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/detail")
    @GetMapping("/interactiveCommunication/icPublicOpinionCollect/detail")
    public CommonResult<JSONObject> detail(@Valid IcPublicOpinionCollectIdParam icPublicOpinionCollectIdParam) {
        return CommonResult.data(icPublicOpinionCollectService.detail(icPublicOpinionCollectIdParam));
    }

    /**
     * 审核留言-通过、不通过
     *
     * @author hjc
     * @date 2024/05/23 23:40
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("审核留言-通过、不通过")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollectMessage/detail")
    @PostMapping("/interactiveCommunication/icPublicOpinionCollect/auditStatus")
    public CommonResult<String> auditStatus(@RequestBody @Valid IcPublicOpinionAuditStatusParam icPublicOpinionAuditStatusParam) {
        icPublicOpinionCollectService.auditStatus(icPublicOpinionAuditStatusParam);
        return CommonResult.ok();
    }

    /**
     * 获取征集部门信息
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取征集部门信息")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/getIoDepartmentFunction")
    @GetMapping("/interactiveCommunication/icPublicOpinionCollect/getIoDepartmentFunction")
    public CommonResult<List<BizIoDepartmentFunction>> getIoDepartmentFunction() {
        return CommonResult.data(icPublicOpinionCollectService.getIoDepartmentFunction());
    }

    /**
     * 添加互动交流-民意征集管理表
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加互动交流-民意征集管理表")
    @CommonLog("添加互动交流-民意征集管理表")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/add")
    @PostMapping("/interactiveCommunication/icPublicOpinionCollect/add")
    public CommonResult<String> add(@RequestBody @Valid IcPublicOpinionCollectAddParam icPublicOpinionCollectAddParam) {
        icPublicOpinionCollectService.add(icPublicOpinionCollectAddParam);
        return CommonResult.ok();
    }


    /**
     * 网站-分页展示
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("网站-分页展示")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/page")
    @GetMapping("/interactiveCommunication/icPublicOpinionCollect/getSitePage")
    public CommonResult<Page<IcPublicOpinionCollect>> getSitePage(IcPublicOpinionCollectPageParam icPublicOpinionCollectPageParam) {
        return CommonResult.data(icPublicOpinionCollectService.getSitePage(icPublicOpinionCollectPageParam));
    }

    /**
     * 网站-详情
     *
     * @author hjc
     * @date 2024/05/23 19:44
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站-详情")
    // @SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/detail")
    @GetMapping("/interactiveCommunication/icPublicOpinionCollect/siteDetail")
    public CommonResult<JSONObject> siteDetail(@Valid IcPublicOpinionCollectIdParam icPublicOpinionCollectIdParam) {
        return CommonResult.data(icPublicOpinionCollectService.siteDetail(icPublicOpinionCollectIdParam));
    }
    /*    *
     * 编辑互动交流-民意征集管理表
     *
     * @author hjc
     * @date  2024/05/23 19:44*/

    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑互动交流-民意征集管理表")
    @CommonLog("编辑互动交流-民意征集管理表")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/edit")
    @PostMapping("/interactiveCommunication/icPublicOpinionCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid IcPublicOpinionCollectEditParam icPublicOpinionCollectEditParam) {
        icPublicOpinionCollectService.edit(icPublicOpinionCollectEditParam);
        return CommonResult.ok();
    }
    /*

     */
/**
 * 删除互动交流-民意征集管理表
 *
 * @author hjc
 * @date 2024/05/23 19:44
 *//*

    @ApiOperationSupport(order = 4)
    @ApiOperation("删除互动交流-民意征集管理表")
    @CommonLog("删除互动交流-民意征集管理表")
    //@SaCheckPermission("/interactiveCommunication/icPublicOpinionCollect/delete")
    @PostMapping("/interactiveCommunication/icPublicOpinionCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<IcPublicOpinionCollectIdParam> icPublicOpinionCollectIdParamList) {
        icPublicOpinionCollectService.delete(icPublicOpinionCollectIdParamList);
        return CommonResult.ok();
    }
*/


}
