/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.entity.IcPublicOpinionCollect;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.mapper.IcPublicOpinionCollectMapper;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.entity.IcPublicOpinionCollectMessage;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.mapper.IcPublicOpinionCollectMessageMapper;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.param.IcPublicOpinionCollectMessageAddParam;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.param.IcPublicOpinionCollectMessageEditParam;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.param.IcPublicOpinionCollectMessageIdParam;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.param.IcPublicOpinionCollectMessagePageParam;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollectMessage.service.IcPublicOpinionCollectMessageService;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.List;

/**
 * 互动交流-民意征集管理-留言表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/23 23:40
 **/
@Service
public class IcPublicOpinionCollectMessageServiceImpl extends ServiceImpl<IcPublicOpinionCollectMessageMapper, IcPublicOpinionCollectMessage> implements IcPublicOpinionCollectMessageService {

    @Autowired
    private IcPublicOpinionCollectMapper icPublicOpinionCollectMapper;

    @Override
    public Page<IcPublicOpinionCollectMessage> page(IcPublicOpinionCollectMessagePageParam icPublicOpinionCollectMessagePageParam) {
        QueryWrapper<IcPublicOpinionCollectMessage> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isAllNotEmpty(icPublicOpinionCollectMessagePageParam.getSortField(), icPublicOpinionCollectMessagePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(icPublicOpinionCollectMessagePageParam.getSortOrder());
            queryWrapper.orderBy(true, icPublicOpinionCollectMessagePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(icPublicOpinionCollectMessagePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(IcPublicOpinionCollectMessage::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(IcPublicOpinionCollectMessageAddParam icPublicOpinionCollectMessageAddParam) {

        IcPublicOpinionCollect icPublicOpinionCollect = icPublicOpinionCollectMapper
                .selectById(icPublicOpinionCollectMessageAddParam.getPublicOpinionCollectId());

        LocalDateTime now = LocalDateTime.now();
        Instant instant = icPublicOpinionCollect.getEndTime().toInstant();
        LocalDateTime endTime = instant.atZone(ZoneId.systemDefault()).toLocalDateTime();

        Instant startTimeInstant = icPublicOpinionCollect.getStartTime().toInstant();
        LocalDateTime startTme = startTimeInstant.atZone(ZoneId.systemDefault()).toLocalDateTime();

        if (now.isAfter(endTime)) {
            throw new CommonException("征集时间已结束，不可进行留言!");
        }
        if (now.isBefore(startTme)){
            throw new CommonException("征集时间还未开始，不可进行留言!");
        }

        IcPublicOpinionCollectMessage icPublicOpinionCollectMessage = BeanUtil.toBean(icPublicOpinionCollectMessageAddParam, IcPublicOpinionCollectMessage.class);
        this.save(icPublicOpinionCollectMessage);

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(IcPublicOpinionCollectMessageEditParam icPublicOpinionCollectMessageEditParam) {
        IcPublicOpinionCollectMessage icPublicOpinionCollectMessage = this.queryEntity(icPublicOpinionCollectMessageEditParam.getId());
        BeanUtil.copyProperties(icPublicOpinionCollectMessageEditParam, icPublicOpinionCollectMessage);
        this.updateById(icPublicOpinionCollectMessage);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<IcPublicOpinionCollectMessageIdParam> icPublicOpinionCollectMessageIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(icPublicOpinionCollectMessageIdParamList, IcPublicOpinionCollectMessageIdParam::getId));
    }

    @Override
    public IcPublicOpinionCollectMessage detail(IcPublicOpinionCollectMessageIdParam icPublicOpinionCollectMessageIdParam) {
        return this.queryEntity(icPublicOpinionCollectMessageIdParam.getId());
    }

    @Override
    public IcPublicOpinionCollectMessage queryEntity(String id) {
        IcPublicOpinionCollectMessage icPublicOpinionCollectMessage = this.getById(id);
        if (ObjectUtil.isEmpty(icPublicOpinionCollectMessage)) {
            throw new CommonException("互动交流-民意征集管理-留言表不存在，id值为：{}", id);
        }
        return icPublicOpinionCollectMessage;
    }
}
