/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativeDocument.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAdministrativeDocument.param.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogAdministrativeDocument.entity.OgAdministrativeDocument;
import com.unis.openGovernment.modular.ogAdministrativeDocument.mapper.OgAdministrativeDocumentMapper;
import com.unis.openGovernment.modular.ogAdministrativeDocument.service.OgAdministrativeDocumentService;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 政务公开-行政规范性文件管理表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/22 14:48
 **/
@Service
public class OgAdministrativeDocumentServiceImpl extends ServiceImpl<OgAdministrativeDocumentMapper, OgAdministrativeDocument> implements OgAdministrativeDocumentService {


    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 100000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyy";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);

    @Autowired
    private OgAdministrativeDocumentMapper ogAdministrativeDocumentMapper;
    @Override
    public Page<OgAdministrativeDocument> page(OgAdministrativeDocumentPageParam ogAdministrativeDocumentPageParam) {
        QueryWrapper<OgAdministrativeDocument> queryWrapper = new QueryWrapper<>();

        if (StringUtils.isNotEmpty(ogAdministrativeDocumentPageParam.getDocumentName())){
            queryWrapper.like("document_name",ogAdministrativeDocumentPageParam.getDocumentName());
        }
        if(ObjectUtil.isAllNotEmpty(ogAdministrativeDocumentPageParam.getSortField(), ogAdministrativeDocumentPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativeDocumentPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativeDocumentPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativeDocumentPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativeDocument::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgAdministrativeDocumentAddParam ogAdministrativeDocumentAddParam) {
        OgAdministrativeDocument ogAdministrativeDocument = BeanUtil.toBean(ogAdministrativeDocumentAddParam, OgAdministrativeDocument.class);

        sequenceNumbers.putIfAbsent("01284", 0);
        // 增加当前货位的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get("01284") + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put("01284", sequenceNumber);
        // 确保顺序号是4位数
        String formattedSequenceNumber = String.format("%05d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并、日期和顺序号
        String indexNumber = "01284"+"/" + currentDate +"-"+ formattedSequenceNumber;

        ogAdministrativeDocument.setIndexNumber(indexNumber);

        this.save(ogAdministrativeDocument);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgAdministrativeDocumentEditParam ogAdministrativeDocumentEditParam) {
        OgAdministrativeDocument ogAdministrativeDocument = this.queryEntity(ogAdministrativeDocumentEditParam.getId());
        BeanUtil.copyProperties(ogAdministrativeDocumentEditParam, ogAdministrativeDocument);
        this.updateById(ogAdministrativeDocument);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgAdministrativeDocumentIdParam> ogAdministrativeDocumentIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogAdministrativeDocumentIdParamList, OgAdministrativeDocumentIdParam::getId));
    }

    @Override
    public OgAdministrativeDocument detail(OgAdministrativeDocumentIdParam ogAdministrativeDocumentIdParam) {
        return this.queryEntity(ogAdministrativeDocumentIdParam.getId());
    }

    @Override
    public OgAdministrativeDocument queryEntity(String id) {
        OgAdministrativeDocument ogAdministrativeDocument = this.getById(id);
        if(ObjectUtil.isEmpty(ogAdministrativeDocument)) {
            throw new CommonException("政务公开-行政规范性文件管理表不存在，id值为：{}", id);
        }
        return ogAdministrativeDocument;
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgAdministrativeDocumentAndStatusParam> paramCommonValidList) {
        for (OgAdministrativeDocumentAndStatusParam documentAndStatusParam : paramCommonValidList) {

            OgAdministrativeDocument ogAdministrativeDocument = this.queryEntity(documentAndStatusParam.getId());
            ogAdministrativeDocument.setStatus(documentAndStatusParam.getStatus());

            this.updateById(ogAdministrativeDocument);
        }
    }

    /**
     * 网站-获取行政规范性文件
     *
     * @author hjc
     * @date  2024/05/22 14:48
     */
    @Override
    public Page<OgAdministrativeDocument> getAll(OgAdministrativeDocumentPageParam ogAdministrativeDocumentPageParam) {
        QueryWrapper<OgAdministrativeDocument> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgAdministrativeDocument::getStatus,2);
        if(ObjectUtil.isAllNotEmpty(ogAdministrativeDocumentPageParam.getSortField(), ogAdministrativeDocumentPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativeDocumentPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativeDocumentPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativeDocumentPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativeDocument::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
