/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativeLicense.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAdministrativeLicense.entity.OgAdministrativeLicense;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseAddParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseEditParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseIdParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicensePageParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.service.OgAdministrativeLicenseService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 公开内容管理-行政许可表控制器
 *
 * @author hjc
 * @date  2024/05/21 20:54
 */
@Api(tags = "公开内容管理-行政许可表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgAdministrativeLicenseController {

    @Resource
    private OgAdministrativeLicenseService ogAdministrativeLicenseService;

    /**
     * 获取公开内容管理-行政许可表分页
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开内容管理-行政许可表分页")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/page")
    @GetMapping("/openGovernment/ogAdministrativeLicense/page")
    public CommonResult<Page<OgAdministrativeLicense>> page(OgAdministrativeLicensePageParam ogAdministrativeLicensePageParam) {
        return CommonResult.data(ogAdministrativeLicenseService.page(ogAdministrativeLicensePageParam));
    }

    /**
     * 添加公开内容管理-行政许可表
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开内容管理-行政许可表")
    @CommonLog("添加公开内容管理-行政许可表")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/add")
    @PostMapping("/openGovernment/ogAdministrativeLicense/add")
    public CommonResult<String> add(@RequestBody @Valid OgAdministrativeLicenseAddParam ogAdministrativeLicenseAddParam) {
        ogAdministrativeLicenseService.add(ogAdministrativeLicenseAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开内容管理-行政许可表
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开内容管理-行政许可表")
    @CommonLog("编辑公开内容管理-行政许可表")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/edit")
    @PostMapping("/openGovernment/ogAdministrativeLicense/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgAdministrativeLicenseEditParam ogAdministrativeLicenseEditParam) {
        ogAdministrativeLicenseService.edit(ogAdministrativeLicenseEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开内容管理-行政许可表
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开内容管理-行政许可表")
    @CommonLog("删除公开内容管理-行政许可表")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/delete")
    @PostMapping("/openGovernment/ogAdministrativeLicense/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgAdministrativeLicenseIdParam> ogAdministrativeLicenseIdParamList) {
        ogAdministrativeLicenseService.delete(ogAdministrativeLicenseIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开内容管理-行政许可表详情
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取公开内容管理-行政许可表详情")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/detail")
    @GetMapping("/openGovernment/ogAdministrativeLicense/detail")
    public CommonResult<OgAdministrativeLicense> detail(@Valid OgAdministrativeLicenseIdParam ogAdministrativeLicenseIdParam) {
        return CommonResult.data(ogAdministrativeLicenseService.detail(ogAdministrativeLicenseIdParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogAdministrativeLicense/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        ogAdministrativeLicenseService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }

 /*   *//**
     * 网站-行政许可表详情
     *
     * @author hjc
     * @date  2024/05/21 20:54
     *//*
    @ApiOperationSupport(order = 6)
    @ApiOperation("网站-行政许可表详情")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/detail")
    @GetMapping("/openGovernment/ogAdministrativeLicense/getOgAdministrativeLicense")
    public CommonResult<OgAdministrativeLicense> getOgAdministrativeLicense() {
        return CommonResult.data(ogAdministrativeLicenseService.getOgAdministrativeLicense());
    }
*/
    /**
     * 网站-行政许可表分页
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("网站-行政许可表分页")
    //@SaCheckPermission("/openGovernment/ogAdministrativeLicense/page")
    @GetMapping("/openGovernment/ogAdministrativeLicense/OgAdministrativeLicensePage")
    public CommonResult<Page<OgAdministrativeLicense>> OgAdministrativeLicensePage(OgAdministrativeLicensePageParam ogAdministrativeLicensePageParam) {
        return CommonResult.data(ogAdministrativeLicenseService.OgAdministrativeLicensePage(ogAdministrativeLicensePageParam));
    }

}
