/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativeLicense.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 公开内容管理-行政许可表添加参数
 *
 * @author hjc
 * @date  2024/05/21 20:54
 **/
@Getter
@Setter
public class OgAdministrativeLicenseAddParam {

    /** 企业名称 */
    @ApiModelProperty(value = "企业名称", position = 6)
    @NotBlank(message = "企业名称不能为空")
    private String enterpriseName;

    /** 统一社会信用代码 */
    @ApiModelProperty(value = "统一社会信用代码", position = 7)
    private String creditCode;

    /** 行政许可决定书文号 */
    @ApiModelProperty(value = "行政许可决定书文号", position = 8)
    private String licenseNumber;

    /** 法定代表人姓名 */
    @ApiModelProperty(value = "法定代表人姓名", position = 9)
    private String legalRepresentative;

    /** 有效期自 */
    @ApiModelProperty(value = "有效期自", position = 10)
    @DateTimeFormat(pattern="yyyy-MM-dd")
    private Date validityStart;

    /** 有效期至 */
    @ApiModelProperty(value = "有效期至", position = 11)
    @DateTimeFormat(pattern="yyyy-MM-dd")
    private Date validityEnd;

    /** 许可机关 */
    @ApiModelProperty(value = "许可机关", position = 12)
    private String licensor;

    /** 许可内容 */
    @ApiModelProperty(value = "许可内容", position = 13)
    private String licenseContent;

    /** 公告内容 */
    @ApiModelProperty(value = "公告内容", position = 14)
    @NotBlank(message = "公告内容不能为空")
    private String announcementContent;

    /** 附件，多个附件用","分割 */
    @ApiModelProperty(value = "附件，多个附件用,分割", position = 15)
    private String attachments;

    /** 状态，1：保存；2：提交（启用）；3：禁用 */
    @ApiModelProperty(value = "状态，1：保存；2：提交（启用）；3：禁用", position = 16)
    @NotNull(message = "状态不能为空")
    private Integer status;

}
