/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativeLicense.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAdministrativePenalty.entity.OgAdministrativePenalty;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogAdministrativeLicense.entity.OgAdministrativeLicense;
import com.unis.openGovernment.modular.ogAdministrativeLicense.mapper.OgAdministrativeLicenseMapper;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseAddParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseEditParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicenseIdParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.param.OgAdministrativeLicensePageParam;
import com.unis.openGovernment.modular.ogAdministrativeLicense.service.OgAdministrativeLicenseService;

import java.util.List;
import java.util.Objects;

/**
 * 公开内容管理-行政许可表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/21 20:54
 **/
@Service
public class OgAdministrativeLicenseServiceImpl extends ServiceImpl<OgAdministrativeLicenseMapper, OgAdministrativeLicense> implements OgAdministrativeLicenseService {

    @Autowired
    private OgAdministrativeLicenseMapper ogAdministrativeLicenseMapper;
    @Override
    public Page<OgAdministrativeLicense> page(OgAdministrativeLicensePageParam ogAdministrativeLicensePageParam) {
        QueryWrapper<OgAdministrativeLicense> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogAdministrativeLicensePageParam.getEnterpriseName())){
            queryWrapper.like("enterprise_name",ogAdministrativeLicensePageParam.getEnterpriseName());
        }
        if(ObjectUtil.isAllNotEmpty(ogAdministrativeLicensePageParam.getSortField(), ogAdministrativeLicensePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativeLicensePageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativeLicensePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativeLicensePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativeLicense::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgAdministrativeLicenseAddParam ogAdministrativeLicenseAddParam) {

        List<OgAdministrativeLicense> ogAdministrativeLicenses = ogAdministrativeLicenseMapper.selectList(Wrappers.lambdaQuery(OgAdministrativeLicense.class)
                .eq(OgAdministrativeLicense::getCreditCode, ogAdministrativeLicenseAddParam.getCreditCode()));
        if (CollectionUtils.isNotEmpty(ogAdministrativeLicenses)){
            throw new CommonException("统一社会信用代码重复，请重新输入");
        }

        OgAdministrativeLicense ogAdministrativeLicense = BeanUtil.toBean(ogAdministrativeLicenseAddParam, OgAdministrativeLicense.class);
        this.save(ogAdministrativeLicense);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgAdministrativeLicenseEditParam ogAdministrativeLicenseEditParam) {

        List<OgAdministrativeLicense> ogAdministrativeLicenses = ogAdministrativeLicenseMapper.selectList(Wrappers.lambdaQuery(OgAdministrativeLicense.class)
                .eq(OgAdministrativeLicense::getCreditCode, ogAdministrativeLicenseEditParam.getCreditCode()));
        if (CollectionUtils.isNotEmpty(ogAdministrativeLicenses) && !Objects.equals(ogAdministrativeLicenses.get(0).getId(), ogAdministrativeLicenseEditParam.getId())){
            throw new CommonException("统一社会信用代码重复，请重新输入");
        }

        OgAdministrativeLicense ogAdministrativeLicense = this.queryEntity(ogAdministrativeLicenseEditParam.getId());
        BeanUtil.copyProperties(ogAdministrativeLicenseEditParam, ogAdministrativeLicense);
        this.updateById(ogAdministrativeLicense);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgAdministrativeLicenseIdParam> ogAdministrativeLicenseIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogAdministrativeLicenseIdParamList, OgAdministrativeLicenseIdParam::getId));
    }

    @Override
    public OgAdministrativeLicense detail(OgAdministrativeLicenseIdParam ogAdministrativeLicenseIdParam) {
        return this.queryEntity(ogAdministrativeLicenseIdParam.getId());
    }

    @Override
    public OgAdministrativeLicense queryEntity(String id) {
        OgAdministrativeLicense ogAdministrativeLicense = this.getById(id);
        if(ObjectUtil.isEmpty(ogAdministrativeLicense)) {
            throw new CommonException("公开内容管理-行政许可表不存在，id值为：{}", id);
        }
        return ogAdministrativeLicense;
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {

        for (OgGovernmentAndStatusParam ogGovernmentAndStatusParam : paramCommonValidList) {
            OgAdministrativeLicense ogAdministrativeLicense = this.queryEntity(ogGovernmentAndStatusParam.getId());
            ogAdministrativeLicense.setStatus(ogGovernmentAndStatusParam.getStatus());
            this.updateById(ogAdministrativeLicense);
        }
    }


    /**
     * 网站-行政许可表详情
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @Override
    public OgAdministrativeLicense getOgAdministrativeLicense() {

        List<OgAdministrativeLicense> ogAdministrativeLicenses = ogAdministrativeLicenseMapper.selectList(Wrappers.lambdaQuery(OgAdministrativeLicense.class)
                .eq(OgAdministrativeLicense::getStatus, 2));
        if (CollectionUtil.isNotEmpty(ogAdministrativeLicenses)){
            throw new CommonException("暂无发布数据");
        }
        return ogAdministrativeLicenses.get(0);
    }

    /**
     * 网站-行政许可表分页
     *
     * @author hjc
     * @date  2024/05/21 20:54
     */
    @Override
    public Page<OgAdministrativeLicense> OgAdministrativeLicensePage(OgAdministrativeLicensePageParam ogAdministrativeLicensePageParam) {

        QueryWrapper<OgAdministrativeLicense> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgAdministrativeLicense::getStatus,2);
        if(ObjectUtil.isAllNotEmpty(ogAdministrativeLicensePageParam.getSortField(), ogAdministrativeLicensePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativeLicensePageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativeLicensePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativeLicensePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativeLicense::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
