/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativePenalty.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAdministrativePenalty.entity.OgAdministrativePenalty;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyAddParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyEditParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyIdParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyPageParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.service.OgAdministrativePenaltyService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 公开内容管理-行政处罚表控制器
 *
 * @author hjc
 * @date  2024/05/20 20:57
 */
@Api(tags = "公开内容管理-行政处罚表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgAdministrativePenaltyController {

    @Resource
    private OgAdministrativePenaltyService ogAdministrativePenaltyService;

    /**
     * 获取公开内容管理-行政处罚表分页
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开内容管理-行政处罚表分页")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/page")
    @GetMapping("/openGovernment/ogAdministrativePenalty/page")
    public CommonResult<Page<OgAdministrativePenalty>> page(OgAdministrativePenaltyPageParam ogAdministrativePenaltyPageParam) {
        return CommonResult.data(ogAdministrativePenaltyService.page(ogAdministrativePenaltyPageParam));
    }

    /**
     * 添加公开内容管理-行政处罚表
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开内容管理-行政处罚表")
    @CommonLog("添加公开内容管理-行政处罚表")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/add")
    @PostMapping("/openGovernment/ogAdministrativePenalty/add")
    public CommonResult<String> add(@RequestBody @Valid OgAdministrativePenaltyAddParam ogAdministrativePenaltyAddParam) {
        ogAdministrativePenaltyService.add(ogAdministrativePenaltyAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开内容管理-行政处罚表
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开内容管理-行政处罚表")
    @CommonLog("编辑公开内容管理-行政处罚表")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/edit")
    @PostMapping("/openGovernment/ogAdministrativePenalty/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgAdministrativePenaltyEditParam ogAdministrativePenaltyEditParam) {
        ogAdministrativePenaltyService.edit(ogAdministrativePenaltyEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开内容管理-行政处罚表
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开内容管理-行政处罚表")
    @CommonLog("删除公开内容管理-行政处罚表")
   // @SaCheckPermission("/openGovernment/ogAdministrativePenalty/delete")
    @PostMapping("/openGovernment/ogAdministrativePenalty/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgAdministrativePenaltyIdParam> ogAdministrativePenaltyIdParamList) {
        ogAdministrativePenaltyService.delete(ogAdministrativePenaltyIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开内容管理-行政处罚表详情
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取公开内容管理-行政处罚表详情")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/detail")
    @GetMapping("/openGovernment/ogAdministrativePenalty/detail")
    public CommonResult<OgAdministrativePenalty> detail(@Valid OgAdministrativePenaltyIdParam ogAdministrativePenaltyIdParam) {
        return CommonResult.data(ogAdministrativePenaltyService.detail(ogAdministrativePenaltyIdParam));
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogAdministrativePenalty/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        ogAdministrativePenaltyService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }


/*    *//**
     * 网站-行政处罚表详情
     *
     * @author hjc
     * @date  2024/05/20 20:57
     *//*
    @ApiOperationSupport(order = 7)
    @ApiOperation("网站-行政处罚表详情")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/detail")
    @GetMapping("/openGovernment/ogAdministrativePenalty/getOgAdministrativePenalty")
    public CommonResult<OgAdministrativePenalty> getOgAdministrativePenalty() {
        return CommonResult.data(ogAdministrativePenaltyService.getOgAdministrativePenalty());
    }*/

    /**
     * 网站-行政处罚表分页
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("网站-行政处罚表分页")
    //@SaCheckPermission("/openGovernment/ogAdministrativePenalty/page")
    @GetMapping("/openGovernment/ogAdministrativePenalty/OgAdministrativePenaltyPage")
    public CommonResult<Page<OgAdministrativePenalty>> OgAdministrativePenaltyPage(OgAdministrativePenaltyPageParam ogAdministrativePenaltyPageParam) {
        return CommonResult.data(ogAdministrativePenaltyService.OgAdministrativePenaltyPage(ogAdministrativePenaltyPageParam));
    }
}
