/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAdministrativePenalty.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogDutyBasis.entity.OgDutyBasis;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogAdministrativePenalty.entity.OgAdministrativePenalty;
import com.unis.openGovernment.modular.ogAdministrativePenalty.mapper.OgAdministrativePenaltyMapper;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyAddParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyEditParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyIdParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.param.OgAdministrativePenaltyPageParam;
import com.unis.openGovernment.modular.ogAdministrativePenalty.service.OgAdministrativePenaltyService;

import java.util.List;
import java.util.Objects;

/**
 * 公开内容管理-行政处罚表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/20 20:57
 **/
@Service
public class OgAdministrativePenaltyServiceImpl extends ServiceImpl<OgAdministrativePenaltyMapper, OgAdministrativePenalty> implements OgAdministrativePenaltyService {

    @Autowired
    private OgAdministrativePenaltyMapper ogAdministrativePenaltyMapper;

    @Override
    public Page<OgAdministrativePenalty> page(OgAdministrativePenaltyPageParam ogAdministrativePenaltyPageParam) {
        QueryWrapper<OgAdministrativePenalty> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogAdministrativePenaltyPageParam.getPunishedEntity())){
            queryWrapper.like("punished_entity",ogAdministrativePenaltyPageParam.getPunishedEntity());
        }
        if (ObjectUtil.isAllNotEmpty(ogAdministrativePenaltyPageParam.getSortField(), ogAdministrativePenaltyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativePenaltyPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativePenaltyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativePenaltyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativePenalty::getPunishmentTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgAdministrativePenaltyAddParam ogAdministrativePenaltyAddParam) {
        List<OgAdministrativePenalty> ogAdministrativePenalties = ogAdministrativePenaltyMapper
                .selectList(Wrappers.lambdaQuery(OgAdministrativePenalty.class)
                        .eq(OgAdministrativePenalty::getCreditCode, ogAdministrativePenaltyAddParam.getCreditCode()));
        if (CollectionUtils.isNotEmpty(ogAdministrativePenalties)) {
            throw new CommonException("统一社会信用代码重复，请重新输入");
        }
        OgAdministrativePenalty ogAdministrativePenalty = BeanUtil.toBean(ogAdministrativePenaltyAddParam, OgAdministrativePenalty.class);
        this.save(ogAdministrativePenalty);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgAdministrativePenaltyEditParam ogAdministrativePenaltyEditParam) {

        List<OgAdministrativePenalty> ogAdministrativePenalties = ogAdministrativePenaltyMapper
                .selectList(Wrappers.lambdaQuery(OgAdministrativePenalty.class)
                        .eq(OgAdministrativePenalty::getCreditCode, ogAdministrativePenaltyEditParam.getCreditCode()));
        if (CollectionUtils.isNotEmpty(ogAdministrativePenalties) && !Objects.equals(ogAdministrativePenalties.get(0).getId(),
                ogAdministrativePenaltyEditParam.getId())) {
            throw new CommonException("统一社会信用代码重复，请重新输入");
        }

        OgAdministrativePenalty ogAdministrativePenalty = this.queryEntity(ogAdministrativePenaltyEditParam.getId());
        BeanUtil.copyProperties(ogAdministrativePenaltyEditParam, ogAdministrativePenalty);
        this.updateById(ogAdministrativePenalty);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgAdministrativePenaltyIdParam> ogAdministrativePenaltyIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogAdministrativePenaltyIdParamList, OgAdministrativePenaltyIdParam::getId));
    }

    @Override
    public OgAdministrativePenalty detail(OgAdministrativePenaltyIdParam ogAdministrativePenaltyIdParam) {
        return this.queryEntity(ogAdministrativePenaltyIdParam.getId());
    }

    @Override
    public OgAdministrativePenalty queryEntity(String id) {
        OgAdministrativePenalty ogAdministrativePenalty = this.getById(id);
        if (ObjectUtil.isEmpty(ogAdministrativePenalty)) {
            throw new CommonException("公开内容管理-行政处罚表不存在，id值为：{}", id);
        }
        return ogAdministrativePenalty;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {

        for (OgGovernmentAndStatusParam ogGovernmentAndStatusParam : paramCommonValidList) {

            OgAdministrativePenalty ogAdministrativePenalty = this.queryEntity(ogGovernmentAndStatusParam.getId());
            ogAdministrativePenalty.setStatus(ogGovernmentAndStatusParam.getStatus());
            this.updateById(ogAdministrativePenalty);
        }
    }

    /**
     * 网站-行政处罚表详情
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @Override
    public OgAdministrativePenalty getOgAdministrativePenalty() {
        List<OgAdministrativePenalty> ogAdministrativePenalties = ogAdministrativePenaltyMapper.selectList(Wrappers.lambdaQuery(OgAdministrativePenalty.class)
                .eq(OgAdministrativePenalty::getStatus, 2));
        if (CollectionUtil.isNotEmpty(ogAdministrativePenalties)){
            throw new CommonException("暂无发布数据");
        }
        return ogAdministrativePenalties.get(0);
    }

    /**
     * 网站-行政处罚表分页
     *
     * @author hjc
     * @date  2024/05/20 20:57
     */
    @Override
    public Page<OgAdministrativePenalty> OgAdministrativePenaltyPage(OgAdministrativePenaltyPageParam ogAdministrativePenaltyPageParam) {
        QueryWrapper<OgAdministrativePenalty> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgAdministrativePenalty::getStatus,2);
        if (ObjectUtil.isAllNotEmpty(ogAdministrativePenaltyPageParam.getSortField(), ogAdministrativePenaltyPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAdministrativePenaltyPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAdministrativePenaltyPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAdministrativePenaltyPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAdministrativePenalty::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
