/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogAnnualReport.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAnnualReport.param.*;
import com.unis.openGovernment.modular.ogDutyBasis.param.OgDutyBasisAndStatusParam;
import com.unis.openGovernment.modular.ogPublicSystem.entity.OgPublicSystem;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogAnnualReport.entity.OgAnnualReport;
import com.unis.openGovernment.modular.ogAnnualReport.mapper.OgAnnualReportMapper;
import com.unis.openGovernment.modular.ogAnnualReport.service.OgAnnualReportService;

import java.util.List;

/**
 * 政务公开-公开年报管理表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/22 09:24
 **/
@Service
public class OgAnnualReportServiceImpl extends ServiceImpl<OgAnnualReportMapper, OgAnnualReport> implements OgAnnualReportService {

    @Autowired
    private OgAnnualReportMapper ogAnnualReportMapper;
    @Override
    public Page<OgAnnualReport> page(OgAnnualReportPageParam ogAnnualReportPageParam) {
        QueryWrapper<OgAnnualReport> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(ogAnnualReportPageParam.getSortField(), ogAnnualReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAnnualReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAnnualReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAnnualReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAnnualReport::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgAnnualReportAddParam ogAnnualReportAddParam) {
        OgAnnualReport ogAnnualReport = BeanUtil.toBean(ogAnnualReportAddParam, OgAnnualReport.class);
        this.save(ogAnnualReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgAnnualReportEditParam ogAnnualReportEditParam) {
        OgAnnualReport ogAnnualReport = this.queryEntity(ogAnnualReportEditParam.getId());
        BeanUtil.copyProperties(ogAnnualReportEditParam, ogAnnualReport);
        this.updateById(ogAnnualReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgAnnualReportIdParam> ogAnnualReportIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogAnnualReportIdParamList, OgAnnualReportIdParam::getId));
    }

    @Override
    public OgAnnualReport detail(OgAnnualReportIdParam ogAnnualReportIdParam) {
        return this.queryEntity(ogAnnualReportIdParam.getId());
    }

    @Override
    public OgAnnualReport queryEntity(String id) {
        OgAnnualReport ogAnnualReport = this.getById(id);
        if(ObjectUtil.isEmpty(ogAnnualReport)) {
            throw new CommonException("政务公开-公开年报管理表不存在，id值为：{}", id);
        }
        return ogAnnualReport;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgAnnualReportAndStatusParam> paramCommonValidList) {

        for (OgAnnualReportAndStatusParam ogAnnualReportAndStatusParam : paramCommonValidList) {
            OgAnnualReport ogAnnualReport = this.queryEntity(ogAnnualReportAndStatusParam.getId());
            ogAnnualReport.setStatus(ogAnnualReportAndStatusParam.getStatus());

            this.updateById(ogAnnualReport);
        }

    }
    /**
     * 网站-获取公开年报
     *
     * @author hjc
     * @date  2024/05/22 09:24
     */
    @Override
    public Page<OgAnnualReport> getAll(OgAnnualReportPageParam ogAnnualReportPageParam) {
        QueryWrapper<OgAnnualReport> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgAnnualReport::getStatus,2);
        if(ObjectUtil.isAllNotEmpty(ogAnnualReportPageParam.getSortField(), ogAnnualReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogAnnualReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogAnnualReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogAnnualReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgAnnualReport::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
