/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogDutyBasis.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogDutyBasis.param.*;
import com.unis.openGovernment.modular.ogPolicyFile.param.OgPolicyFileIdAndStatusParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogDutyBasis.entity.OgDutyBasis;
import com.unis.openGovernment.modular.ogDutyBasis.service.OgDutyBasisService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 公开内容管理-履职依据表控制器
 *
 * @author hjc
 * @date  2024/05/20 19:34
 */
@Api(tags = "公开内容管理-履职依据表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgDutyBasisController {

    @Resource
    private OgDutyBasisService ogDutyBasisService;

    /**
     * 获取公开内容管理-履职依据表分页
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开内容管理-履职依据表分页")
   // @SaCheckPermission("/openGovernment/ogDutyBasis/page")
    @GetMapping("/openGovernment/ogDutyBasis/page")
    public CommonResult<Page<OgDutyBasis>> page(OgDutyBasisPageParam ogDutyBasisPageParam) {
        return CommonResult.data(ogDutyBasisService.page(ogDutyBasisPageParam));
    }

    /**
     * 添加公开内容管理-履职依据表
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开内容管理-履职依据表")
    @CommonLog("添加公开内容管理-履职依据表")
    //@SaCheckPermission("/openGovernment/ogDutyBasis/add")
    @PostMapping("/openGovernment/ogDutyBasis/add")
    public CommonResult<String> add(@RequestBody @Valid OgDutyBasisAddParam ogDutyBasisAddParam) {
        ogDutyBasisService.add(ogDutyBasisAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开内容管理-履职依据表
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开内容管理-履职依据表")
    @CommonLog("编辑公开内容管理-履职依据表")
    //@SaCheckPermission("/openGovernment/ogDutyBasis/edit")
    @PostMapping("/openGovernment/ogDutyBasis/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgDutyBasisEditParam ogDutyBasisEditParam) {
        ogDutyBasisService.edit(ogDutyBasisEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开内容管理-履职依据表
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开内容管理-履职依据表")
    @CommonLog("删除公开内容管理-履职依据表")
    //@SaCheckPermission("/openGovernment/ogDutyBasis/delete")
    @PostMapping("/openGovernment/ogDutyBasis/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgDutyBasisIdParam> ogDutyBasisIdParamList) {
        ogDutyBasisService.delete(ogDutyBasisIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开内容管理-履职依据表详情
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取公开内容管理-履职依据表详情")
    //@SaCheckPermission("/openGovernment/ogDutyBasis/detail")
    @GetMapping("/openGovernment/ogDutyBasis/detail")
    public CommonResult<OgDutyBasis> detail(@Valid OgDutyBasisIdParam ogDutyBasisIdParam) {
        return CommonResult.data(ogDutyBasisService.detail(ogDutyBasisIdParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogDutyBasis/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgDutyBasisAndStatusParam> paramCommonValidList) {
        ogDutyBasisService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }

    /**
     * 网站-履职依据表详情
     *
     * @author hjc
     * @date  2024/05/20 19:34
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("网站-履职依据表详情")
    //@SaCheckPermission("/openGovernment/ogDutyBasis/detail")
    @GetMapping("/openGovernment/ogDutyBasis/getOgDutyBasis")
    public CommonResult<OgDutyBasis> getOgDutyBasis() {
        return CommonResult.data(ogDutyBasisService.getOgDutyBasis());
    }



}
