/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogDutyBasis.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogDutyBasis.param.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogDutyBasis.entity.OgDutyBasis;
import com.unis.openGovernment.modular.ogDutyBasis.mapper.OgDutyBasisMapper;
import com.unis.openGovernment.modular.ogDutyBasis.service.OgDutyBasisService;

import java.util.List;

/**
 * 公开内容管理-履职依据表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/20 19:34
 **/
@Service
public class OgDutyBasisServiceImpl extends ServiceImpl<OgDutyBasisMapper, OgDutyBasis> implements OgDutyBasisService {

    @Autowired
    private OgDutyBasisMapper ogDutyBasisMapper;

    @Override
    public Page<OgDutyBasis> page(OgDutyBasisPageParam ogDutyBasisPageParam) {
        QueryWrapper<OgDutyBasis> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogDutyBasisPageParam.getTitle())) {
            queryWrapper.like("title", ogDutyBasisPageParam.getTitle());
        }
        if (ObjectUtil.isAllNotEmpty(ogDutyBasisPageParam.getSortField(), ogDutyBasisPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogDutyBasisPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogDutyBasisPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogDutyBasisPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgDutyBasis::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgDutyBasisAddParam ogDutyBasisAddParam) {
        OgDutyBasis ogDutyBasis = BeanUtil.toBean(ogDutyBasisAddParam, OgDutyBasis.class);
        this.save(ogDutyBasis);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgDutyBasisEditParam ogDutyBasisEditParam) {
        OgDutyBasis ogDutyBasis = this.queryEntity(ogDutyBasisEditParam.getId());
        BeanUtil.copyProperties(ogDutyBasisEditParam, ogDutyBasis);
        this.updateById(ogDutyBasis);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgDutyBasisIdParam> ogDutyBasisIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogDutyBasisIdParamList, OgDutyBasisIdParam::getId));
    }

    @Override
    public OgDutyBasis detail(OgDutyBasisIdParam ogDutyBasisIdParam) {
        return this.queryEntity(ogDutyBasisIdParam.getId());
    }

    @Override
    public OgDutyBasis queryEntity(String id) {
        OgDutyBasis ogDutyBasis = this.getById(id);
        if (ObjectUtil.isEmpty(ogDutyBasis)) {
            throw new CommonException("公开内容管理-履职依据表不存在，id值为：{}", id);
        }
        return ogDutyBasis;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgDutyBasisAndStatusParam> paramCommonValidList) {

        for (OgDutyBasisAndStatusParam ogDutyBasisAndStatusParam : paramCommonValidList) {
            OgDutyBasis ogDutyBasis = this.queryEntity(ogDutyBasisAndStatusParam.getId());

            ogDutyBasis.setStatus(ogDutyBasisAndStatusParam.getStatus());

            this.updateById(ogDutyBasis);
        }

    }

    /**
     * 网站-履职依据表详情
     *
     * @author hjc
     * @date 2024/05/20 19:34
     */
    @Override
    public OgDutyBasis getOgDutyBasis() {
        List<OgDutyBasis> ogDutyBases = ogDutyBasisMapper.selectList(Wrappers.lambdaQuery(OgDutyBasis.class)
                .eq(OgDutyBasis::getStatus, 2));
        if (CollectionUtil.isEmpty(ogDutyBases)) {
            return null;
        }
        return ogDutyBases.get(0);
    }
}
