/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogFinancialBudget.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPlan.entity.OgPlan;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogFinancialBudget.entity.OgFinancialBudget;
import com.unis.openGovernment.modular.ogFinancialBudget.mapper.OgFinancialBudgetMapper;
import com.unis.openGovernment.modular.ogFinancialBudget.param.OgFinancialBudgetAddParam;
import com.unis.openGovernment.modular.ogFinancialBudget.param.OgFinancialBudgetEditParam;
import com.unis.openGovernment.modular.ogFinancialBudget.param.OgFinancialBudgetIdParam;
import com.unis.openGovernment.modular.ogFinancialBudget.param.OgFinancialBudgetPageParam;
import com.unis.openGovernment.modular.ogFinancialBudget.service.OgFinancialBudgetService;

import java.util.List;

/**
 * 公开内容管理-财政预决算表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/22 09:12
 **/
@Service
public class OgFinancialBudgetServiceImpl extends ServiceImpl<OgFinancialBudgetMapper, OgFinancialBudget> implements OgFinancialBudgetService {

    @Autowired
    private OgFinancialBudgetMapper ogFinancialBudgetMapper;
    @Override
    public Page<OgFinancialBudget> page(OgFinancialBudgetPageParam ogFinancialBudgetPageParam) {
        QueryWrapper<OgFinancialBudget> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogFinancialBudgetPageParam.getTitle())) {
            queryWrapper.like("title", ogFinancialBudgetPageParam.getTitle());
        }
        if (ObjectUtil.isAllNotEmpty(ogFinancialBudgetPageParam.getSortField(), ogFinancialBudgetPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogFinancialBudgetPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogFinancialBudgetPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogFinancialBudgetPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgFinancialBudget::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgFinancialBudgetAddParam ogFinancialBudgetAddParam) {
        OgFinancialBudget ogFinancialBudget = BeanUtil.toBean(ogFinancialBudgetAddParam, OgFinancialBudget.class);
        this.save(ogFinancialBudget);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgFinancialBudgetEditParam ogFinancialBudgetEditParam) {
        OgFinancialBudget ogFinancialBudget = this.queryEntity(ogFinancialBudgetEditParam.getId());
        BeanUtil.copyProperties(ogFinancialBudgetEditParam, ogFinancialBudget);
        this.updateById(ogFinancialBudget);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgFinancialBudgetIdParam> ogFinancialBudgetIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogFinancialBudgetIdParamList, OgFinancialBudgetIdParam::getId));
    }

    @Override
    public OgFinancialBudget detail(OgFinancialBudgetIdParam ogFinancialBudgetIdParam) {
        return this.queryEntity(ogFinancialBudgetIdParam.getId());
    }

    @Override
    public OgFinancialBudget queryEntity(String id) {
        OgFinancialBudget ogFinancialBudget = this.getById(id);
        if (ObjectUtil.isEmpty(ogFinancialBudget)) {
            throw new CommonException("公开内容管理-财政预决算表不存在，id值为：{}", id);
        }
        return ogFinancialBudget;
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        for (OgGovernmentAndStatusParam ogGovernmentAndStatusParam : paramCommonValidList) {
            OgFinancialBudget ogFinancialBudget = this.queryEntity(ogGovernmentAndStatusParam.getId());
            ogFinancialBudget.setStatus(ogGovernmentAndStatusParam.getStatus());
            this.updateById(ogFinancialBudget);
        }
    }

    /**
     * 网站-财政预决算表详情
     *
     * @author hjc
     * @date  2024/05/22 09:12
     */
    @Override
    public OgFinancialBudget getOgFinancialBudget() {
        List<OgFinancialBudget> ogFinancialBudgetList = ogFinancialBudgetMapper.selectList(Wrappers.lambdaQuery(OgFinancialBudget.class)
                .eq(OgFinancialBudget::getStatus, 2));
        if (CollectionUtil.isNotEmpty(ogFinancialBudgetList)){
            throw new CommonException("暂无发布数据");
        }
        return ogFinancialBudgetList.get(0);
    }

    /**
     * 网站-财政预决算表分页
     *
     * @author hjc
     * @date  2024/05/22 09:12
     */
    @Override
    public Page<OgFinancialBudget> ogFinancialBudgetPage(OgFinancialBudgetPageParam ogFinancialBudgetPageParam) {

        QueryWrapper<OgFinancialBudget> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgFinancialBudget::getStatus,2);
        if (ObjectUtil.isAllNotEmpty(ogFinancialBudgetPageParam.getSortField(), ogFinancialBudgetPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogFinancialBudgetPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogFinancialBudgetPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogFinancialBudgetPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgFinancialBudget::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);

    }
}
