/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogOpenInfoRequest.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogOpenInfoRequest.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogOpenInfoRequest.entity.OgOpenInfoRequest;
import com.unis.openGovernment.modular.ogOpenInfoRequest.service.OgOpenInfoRequestService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 政务公开-依公开申请管理表控制器
 *
 * @author hjc
 * @date  2024/05/22 16:19
 */
@Api(tags = "政务公开-依公开申请管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgOpenInfoRequestController {

    @Resource
    private OgOpenInfoRequestService ogOpenInfoRequestService;

    /**
     * 获取政务公开-依公开申请管理表分页
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取政务公开-依公开申请管理表分页")
    //@SaCheckPermission("/openGovernment/ogOpenInfoRequest/page")
    @GetMapping("/openGovernment/ogOpenInfoRequest/page")
    public CommonResult<Page<OgOpenInfoRequest>> page(OgOpenInfoRequestPageParam ogOpenInfoRequestPageParam) {
        return CommonResult.data(ogOpenInfoRequestService.page(ogOpenInfoRequestPageParam));
    }

    /**
     * 网站-依公开申请
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("网站-依公开申请")
    @CommonLog("网站-依公开申请")
    //@SaCheckPermission("/openGovernment/ogOpenInfoRequest/add")
    @PostMapping("/openGovernment/ogOpenInfoRequest/add")
    public CommonResult<FindOgOpenInfoRequestParam> add(@RequestBody @Valid OgOpenInfoRequestAddParam ogOpenInfoRequestAddParam) {

        return CommonResult.data( ogOpenInfoRequestService.add(ogOpenInfoRequestAddParam));
    }

    /**
     * 回复政务公开-依公开申请管理表
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("回复-依公开申请管理表")
    @CommonLog("回复-依公开申请管理表")
   // @SaCheckPermission("/openGovernment/ogOpenInfoRequest/edit")
    @PostMapping("/openGovernment/ogOpenInfoRequest/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgOpenInfoRequestEditParam ogOpenInfoRequestEditParam) {
        ogOpenInfoRequestService.edit(ogOpenInfoRequestEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除政务公开-依公开申请管理表
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除政务公开-依公开申请管理表")
    @CommonLog("删除政务公开-依公开申请管理表")
    //@SaCheckPermission("/openGovernment/ogOpenInfoRequest/delete")
    @PostMapping("/openGovernment/ogOpenInfoRequest/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgOpenInfoRequestIdParam> ogOpenInfoRequestIdParamList) {
        ogOpenInfoRequestService.delete(ogOpenInfoRequestIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取政务公开-依公开申请管理表详情
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取政务公开-依公开申请管理表详情")
   // @SaCheckPermission("/openGovernment/ogOpenInfoRequest/detail")
    @GetMapping("/openGovernment/ogOpenInfoRequest/detail")
    public CommonResult<OgOpenInfoRequest> detail(@Valid OgOpenInfoRequestIdParam ogOpenInfoRequestIdParam) {
        return CommonResult.data(ogOpenInfoRequestService.detail(ogOpenInfoRequestIdParam));
    }

    /**
     * 查询页面
     *
     * @author hjc
     * @date  2024/05/22 16:19
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("查询页面")
    // @SaCheckPermission("/openGovernment/ogOpenInfoRequest/detail")
    @GetMapping("/openGovernment/ogOpenInfoRequest/find")
    public CommonResult<OgOpenInfoRequest> find(FindOgOpenInfoRequestParam findOgOpenInfoRequestParam) {
        return CommonResult.data(ogOpenInfoRequestService.find(findOgOpenInfoRequestParam));
    }
}
