/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPlan.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPlan.entity.OgPlan;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanAddParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanEditParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanIdParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanPageParam;
import com.unis.openGovernment.modular.ogPlan.service.OgPlanService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 公开内容管理-规划计划表控制器
 *
 * @author hjc
 * @date  2024/05/22 09:07
 */
@Api(tags = "公开内容管理-规划计划表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgPlanController {

    @Resource
    private OgPlanService ogPlanService;

    /**
     * 获取公开内容管理-规划计划表分页
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开内容管理-规划计划表分页")
    //@SaCheckPermission("/openGovernment/ogPlan/page")
    @GetMapping("/openGovernment/ogPlan/page")
    public CommonResult<Page<OgPlan>> page(OgPlanPageParam ogPlanPageParam) {
        return CommonResult.data(ogPlanService.page(ogPlanPageParam));
    }

    /**
     * 添加公开内容管理-规划计划表
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开内容管理-规划计划表")
    @CommonLog("添加公开内容管理-规划计划表")
    //@SaCheckPermission("/openGovernment/ogPlan/add")
    @PostMapping("/openGovernment/ogPlan/add")
    public CommonResult<String> add(@RequestBody @Valid OgPlanAddParam ogPlanAddParam) {
        ogPlanService.add(ogPlanAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开内容管理-规划计划表
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开内容管理-规划计划表")
    @CommonLog("编辑公开内容管理-规划计划表")
    //@SaCheckPermission("/openGovernment/ogPlan/edit")
    @PostMapping("/openGovernment/ogPlan/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgPlanEditParam ogPlanEditParam) {
        ogPlanService.edit(ogPlanEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开内容管理-规划计划表
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开内容管理-规划计划表")
    @CommonLog("删除公开内容管理-规划计划表")
    //@SaCheckPermission("/openGovernment/ogPlan/delete")
    @PostMapping("/openGovernment/ogPlan/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgPlanIdParam> ogPlanIdParamList) {
        ogPlanService.delete(ogPlanIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开内容管理-规划计划表详情
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取公开内容管理-规划计划表详情")
    //@SaCheckPermission("/openGovernment/ogPlan/detail")
    @GetMapping("/openGovernment/ogPlan/detail")
    public CommonResult<OgPlan> detail(@Valid OgPlanIdParam ogPlanIdParam) {
        return CommonResult.data(ogPlanService.detail(ogPlanIdParam));
    }



    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogPlan/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        ogPlanService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }

  /*  *//**
     * 网站-规划计划表详情
     *
     * @author hjc
     * @date  2024/05/22 09:07
     *//*
    @ApiOperationSupport(order = 6)
    @ApiOperation("网站-规划计划表详情")
    //@SaCheckPermission("/openGovernment/ogPlan/detail")
    @GetMapping("/openGovernment/ogPlan/getOgPlan")
    public CommonResult<OgPlan> getOgPlan() {
        return CommonResult.data(ogPlanService.getOgPlan());
    }*/

    /**
     * 网页-规划计划表-年度计划分页
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("网页-规划计划表-年度计划分页")
    //@SaCheckPermission("/openGovernment/ogPlan/page")
    @GetMapping("/openGovernment/ogPlan/ogPlanAnnualPlanPage")
    public CommonResult<Page<OgPlan>> ogPlanAnnualPlanPage(OgPlanPageParam ogPlanPageParam) {
        return CommonResult.data(ogPlanService.OgPlanPage(ogPlanPageParam));
    }

    /**
     * 网页-规划计划表-中长期分页
     *
     * @author hjc
     * @date  2024/05/22 09:07
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("网页-规划计划表-中长期分页")
    //@SaCheckPermission("/openGovernment/ogPlan/page")
    @GetMapping("/openGovernment/ogPlan/ogPlanLongTermPage")
    public CommonResult<Page<OgPlan>> ogPlanLongTermPage(OgPlanPageParam ogPlanPageParam) {
        return CommonResult.data(ogPlanService.ogPlanLongTermPage(ogPlanPageParam));
    }
}
