/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPlan.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogAdministrativeLicense.entity.OgAdministrativeLicense;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.OgGovernmentAndStatusParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogPlan.entity.OgPlan;
import com.unis.openGovernment.modular.ogPlan.mapper.OgPlanMapper;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanAddParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanEditParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanIdParam;
import com.unis.openGovernment.modular.ogPlan.param.OgPlanPageParam;
import com.unis.openGovernment.modular.ogPlan.service.OgPlanService;

import java.util.List;

/**
 * 公开内容管理-规划计划表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/22 09:07
 **/
@Service
public class OgPlanServiceImpl extends ServiceImpl<OgPlanMapper, OgPlan> implements OgPlanService {

    @Autowired
    private OgPlanMapper ogPlanMapper;

    @Override
    public Page<OgPlan> page(OgPlanPageParam ogPlanPageParam) {
        QueryWrapper<OgPlan> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogPlanPageParam.getTitle())) {
            queryWrapper.like("title", ogPlanPageParam.getTitle());
        }
        if (ObjectUtil.isAllNotEmpty(ogPlanPageParam.getSortField(), ogPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPlan::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgPlanAddParam ogPlanAddParam) {
        OgPlan ogPlan = BeanUtil.toBean(ogPlanAddParam, OgPlan.class);
        this.save(ogPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgPlanEditParam ogPlanEditParam) {
        OgPlan ogPlan = this.queryEntity(ogPlanEditParam.getId());
        BeanUtil.copyProperties(ogPlanEditParam, ogPlan);
        this.updateById(ogPlan);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgPlanIdParam> ogPlanIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogPlanIdParamList, OgPlanIdParam::getId));
    }

    @Override
    public OgPlan detail(OgPlanIdParam ogPlanIdParam) {
        return this.queryEntity(ogPlanIdParam.getId());
    }

    @Override
    public OgPlan queryEntity(String id) {
        OgPlan ogPlan = this.getById(id);
        if (ObjectUtil.isEmpty(ogPlan)) {
            throw new CommonException("公开内容管理-规划计划表不存在，id值为：{}", id);
        }
        return ogPlan;
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        for (OgGovernmentAndStatusParam ogGovernmentAndStatusParam : paramCommonValidList) {
            OgPlan ogPlan = this.queryEntity(ogGovernmentAndStatusParam.getId());
            ogPlan.setStatus(ogGovernmentAndStatusParam.getStatus());
            this.updateById(ogPlan);
        }
    }

    /**
     * 网站-规划计划表详情
     *
     * @author hjc
     * @date 2024/05/22 09:07
     */
    @Override
    public OgPlan getOgPlan() {
        List<OgPlan> ogPlanList = ogPlanMapper.selectList(Wrappers.lambdaQuery(OgPlan.class)
                .eq(OgPlan::getStatus, 2));
        if (CollectionUtil.isNotEmpty(ogPlanList)) {
            throw new CommonException("暂无发布数据");
        }
        return ogPlanList.get(0);
    }

    /**
     * 网页-规划计划表-年度计划分页
     *
     * @author hjc
     * @date 2024/05/22 09:07
     */
    @Override
    public Page<OgPlan> OgPlanPage(OgPlanPageParam ogPlanPageParam) {
        QueryWrapper<OgPlan> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgPlan::getPlanType, 1);
        queryWrapper.lambda().eq(OgPlan::getStatus, 2);
        if (ObjectUtil.isAllNotEmpty(ogPlanPageParam.getSortField(), ogPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPlan::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);

    }

    /**
     * 网页-规划计划表-中长期分页
     *
     * @author hjc
     * @date 2024/05/22 09:07
     */
    @Override
    public Page<OgPlan> ogPlanLongTermPage(OgPlanPageParam ogPlanPageParam) {
        QueryWrapper<OgPlan> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgPlan::getPlanType, 2);
        queryWrapper.lambda().eq(OgPlan::getStatus, 2);
        if (ObjectUtil.isAllNotEmpty(ogPlanPageParam.getSortField(), ogPlanPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPlanPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPlanPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPlanPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPlan::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
