/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPolicyFile.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogPolicyFile.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPolicyFile.entity.OgPolicyFile;
import com.unis.openGovernment.modular.ogPolicyFile.service.OgPolicyFileService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 政务公开-政策文件控制器
 *
 * @author hjc
 * @date  2024/05/20 16:18
 */
@Api(tags = "政务公开-政策文件控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgPolicyFileController {

    @Resource
    private OgPolicyFileService ogPolicyFileService;

    /**
     * 获取政务公开-政策文件分页
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取政务公开-政策文件分页")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/page")
    @GetMapping("/openGovernment/ogPolicyFile/page")
    public CommonResult<Page<OgPolicyFile>> page(OgPolicyFilePageParam ogPolicyFilePageParam) {
        return CommonResult.data(ogPolicyFileService.page(ogPolicyFilePageParam));
    }

    /**
     * 添加政务公开-政策文件
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加政务公开-政策文件")
    @CommonLog("添加政务公开-政策文件")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/add")
    @PostMapping("/openGovernment/ogPolicyFile/add")
    public CommonResult<String> add(@RequestBody @Valid OgPolicyFileAddParam ogPolicyFileAddParam) {
        ogPolicyFileService.add(ogPolicyFileAddParam);
        return CommonResult.ok();
    }

  /*  *
     * 编辑政务公开-政策文件
     *
     * @author hjc
     * @date  2024/05/20 16:18*/

    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑政务公开-政策文件")
    @CommonLog("编辑政务公开-政策文件")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/edit")
    @PostMapping("/openGovernment/ogPolicyFile/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgPolicyFileEditParam ogPolicyFileEditParam) {
        ogPolicyFileService.edit(ogPolicyFileEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除政务公开-政策文件
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除政务公开-政策文件")
    @CommonLog("删除政务公开-政策文件")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/delete")
    @PostMapping("/openGovernment/ogPolicyFile/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgPolicyFileIdParam> ogPolicyFileIdParamList) {
        ogPolicyFileService.delete(ogPolicyFileIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取政务公开-政策文件详情
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取政务公开-政策文件详情")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/detail")
    @GetMapping("/openGovernment/ogPolicyFile/detail")
    public CommonResult<OgPolicyFile> detail(@Valid OgPolicyFileIdParam ogPolicyFileIdParam) {
        return CommonResult.data(ogPolicyFileService.detail(ogPolicyFileIdParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogPolicyFile/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<OgPolicyFileIdAndStatusParam> ogPolicyFileIdParamList) {
        ogPolicyFileService.enableAndDisable(ogPolicyFileIdParamList);
        return CommonResult.ok();
    }

    /**
     * 网站-获取政策文件
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站-获取政策文件")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/detail")
    @GetMapping("/openGovernment/ogPolicyFile/getAll")
    public CommonResult<Page<OgPolicyFile>> getAll(OgPolicyFilePageParam ogPolicyFilePageParam) {
        return CommonResult.data(ogPolicyFileService.getAll(ogPolicyFilePageParam));
    }
}
