/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPolicyFile.param;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 政务公开-政策文件编辑参数
 *
 * @author hjc
 * @date  2024/05/20 16:18
 **/
@Getter
@Setter
public class OgPolicyFileEditParam {

    /** 记录唯一标识符 */
    @ApiModelProperty(value = "记录唯一标识符", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 公文名称 */
    @ApiModelProperty(value = "公文名称", position = 6)
    @NotBlank(message = "公文名称不能为空")
    private String documentName;

    /** 索引号 */
    @ApiModelProperty(value = "索引号", position = 7)
    private String indexNumber;

    /** 信息来源 */
    @ApiModelProperty(value = "信息来源", position = 8)
    private String informationSource;

    /** 发布日期 */
    @ApiModelProperty(value = "发布日期", position = 9)
    @DateTimeFormat(pattern="yyyy-MM-dd")
    private Date publishDate;

    /** 文号 */
    @ApiModelProperty(value = "文号", position = 10)
    private String documentNumber;

    /** 主题词 */
    @ApiModelProperty(value = "主题词", position = 11)
    private String subjectWord;

    /** 效力状态，0：无效；1：有效； */
    @ApiModelProperty(value = "效力状态，0：无效；1：有效；", position = 12)
    @NotNull(message = "效力状态不能为空")
    private Integer validityStatus;

    /** 公告内容 */
    @ApiModelProperty(value = "公告内容", position = 13)
    @NotBlank(message = "公告内容不能为空")
    private String announcementContent;

    /** 附件，多个附件用","分割 */
    @ApiModelProperty(value = "附件，多个附件用,分割", position = 14)
    private String attachments;

    /** 状态，1：保存；2：提交（启用）；3：禁用 */
    @ApiModelProperty(value = "状态，1：保存；2：提交（启用）；3：禁用", position = 15)
    @NotNull(message = "状态不能为空")
    private Integer status;

}
