/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogProactiveDisclosure.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogDutyBasis.entity.OgDutyBasis;
import com.unis.openGovernment.modular.ogProactiveDisclosure.param.*;
import com.unis.openGovernment.modular.ogPublicGuidance.entity.OgPublicGuidance;
import com.unis.openGovernment.modular.ogPublicGuidance.mapper.OgPublicGuidanceMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogProactiveDisclosure.entity.OgProactiveDisclosure;
import com.unis.openGovernment.modular.ogProactiveDisclosure.mapper.OgProactiveDisclosureMapper;
import com.unis.openGovernment.modular.ogProactiveDisclosure.service.OgProactiveDisclosureService;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 公开内容管理-主动公开文件表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/20 20:31
 **/
@Service
public class OgProactiveDisclosureServiceImpl extends ServiceImpl<OgProactiveDisclosureMapper, OgProactiveDisclosure> implements OgProactiveDisclosureService {

    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 100000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyy";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);


    @Autowired
    private OgProactiveDisclosureMapper ogProactiveDisclosureMapper;

    @Override
    public Page<OgProactiveDisclosure> page(OgProactiveDisclosurePageParam ogProactiveDisclosurePageParam) {
        QueryWrapper<OgProactiveDisclosure> queryWrapper = new QueryWrapper<>();
        if (ObjectUtil.isNotEmpty(ogProactiveDisclosurePageParam.getTitle())) {
            queryWrapper.like("title", ogProactiveDisclosurePageParam.getTitle());
        }
        if (ObjectUtil.isAllNotEmpty(ogProactiveDisclosurePageParam.getSortField(), ogProactiveDisclosurePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogProactiveDisclosurePageParam.getSortOrder());
            queryWrapper.orderBy(true, ogProactiveDisclosurePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogProactiveDisclosurePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgProactiveDisclosure::getDocumentDate);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgProactiveDisclosureAddParam ogProactiveDisclosureAddParam) {
        OgProactiveDisclosure ogProactiveDisclosure = BeanUtil.toBean(ogProactiveDisclosureAddParam, OgProactiveDisclosure.class);

        sequenceNumbers.putIfAbsent("01284", 0);
        // 增加当前货位的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get("01284") + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put("01284", sequenceNumber);
        // 确保顺序号是4位数
        String formattedSequenceNumber = String.format("%05d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并、日期和顺序号
        String indexNumber = "01284" + "/" + currentDate + "-" + formattedSequenceNumber;

        ogProactiveDisclosure.setIndexNumber(indexNumber);

        this.save(ogProactiveDisclosure);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgProactiveDisclosureEditParam ogProactiveDisclosureEditParam) {
        OgProactiveDisclosure ogProactiveDisclosure = this.queryEntity(ogProactiveDisclosureEditParam.getId());
        BeanUtil.copyProperties(ogProactiveDisclosureEditParam, ogProactiveDisclosure);
        this.updateById(ogProactiveDisclosure);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgProactiveDisclosureIdParam> ogProactiveDisclosureIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogProactiveDisclosureIdParamList, OgProactiveDisclosureIdParam::getId));
    }

    @Override
    public OgProactiveDisclosure detail(OgProactiveDisclosureIdParam ogProactiveDisclosureIdParam) {
        return this.queryEntity(ogProactiveDisclosureIdParam.getId());
    }

    @Override
    public OgProactiveDisclosure queryEntity(String id) {
        OgProactiveDisclosure ogProactiveDisclosure = this.getById(id);
        if (ObjectUtil.isEmpty(ogProactiveDisclosure)) {
            throw new CommonException("公开内容管理-主动公开文件表不存在，id值为：{}", id);
        }
        return ogProactiveDisclosure;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgGovernmentAndStatusParam> paramCommonValidList) {
        for (OgGovernmentAndStatusParam ogGovernmentAndStatusParam : paramCommonValidList) {
            OgProactiveDisclosure ogProactiveDisclosure = this.queryEntity(ogGovernmentAndStatusParam.getId());
            ogProactiveDisclosure.setStatus(ogGovernmentAndStatusParam.getStatus());

            this.updateById(ogProactiveDisclosure);
        }
    }

    /**
     * 网站-主动公开文件表详情
     *
     * @author hjc
     * @date  2024/05/20 20:31
     */
    @Override
    public OgProactiveDisclosure getOgProactiveDisclosure() {
        OgProactiveDisclosure ogProactiveDisclosure = ogProactiveDisclosureMapper.selectOne(Wrappers.lambdaQuery(OgProactiveDisclosure.class)
                .eq(OgProactiveDisclosure::getStatus, 2));
        if (ObjectUtil.isNotEmpty(ogProactiveDisclosure)){
            throw new CommonException("暂无发布数据");
        }
        return ogProactiveDisclosure;
    }
}
