/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPublicGuidance.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogPolicyFile.param.OgPolicyFileIdAndStatusParam;
import com.unis.openGovernment.modular.ogPublicGuidance.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPublicGuidance.entity.OgPublicGuidance;
import com.unis.openGovernment.modular.ogPublicGuidance.service.OgPublicGuidanceService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 公开指南管理表控制器
 *
 * @author hjc
 * @date  2024/05/20 17:32
 */
@Api(tags = "公开指南管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgPublicGuidanceController {

    @Resource
    private OgPublicGuidanceService ogPublicGuidanceService;

    /**
     * 获取公开指南管理表分页
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开指南管理表分页")
   // @SaCheckPermission("/openGovernment/ogPublicGuidance/page")
    @GetMapping("/openGovernment/ogPublicGuidance/page")
    public CommonResult<Page<OgPublicGuidance>> page(OgPublicGuidancePageParam ogPublicGuidancePageParam) {
        return CommonResult.data(ogPublicGuidanceService.page(ogPublicGuidancePageParam));
    }

    /**
     * 添加公开指南管理表
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开指南管理表")
    @CommonLog("添加公开指南管理表")
   // @SaCheckPermission("/openGovernment/ogPublicGuidance/add")
    @PostMapping("/openGovernment/ogPublicGuidance/add")
    public CommonResult<String> add(@RequestBody @Valid OgPublicGuidanceAddParam ogPublicGuidanceAddParam) {
        ogPublicGuidanceService.add(ogPublicGuidanceAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开指南管理表
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开指南管理表")
    @CommonLog("编辑公开指南管理表")
    //@SaCheckPermission("/openGovernment/ogPublicGuidance/edit")
    @PostMapping("/openGovernment/ogPublicGuidance/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgPublicGuidanceEditParam ogPublicGuidanceEditParam) {
        ogPublicGuidanceService.edit(ogPublicGuidanceEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开指南管理表
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开指南管理表")
    @CommonLog("删除公开指南管理表")
    //@SaCheckPermission("/openGovernment/ogPublicGuidance/delete")
    @PostMapping("/openGovernment/ogPublicGuidance/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgPublicGuidanceIdParam> ogPublicGuidanceIdParamList) {
        ogPublicGuidanceService.delete(ogPublicGuidanceIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开指南管理表详情
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取公开指南管理表详情")
    //@SaCheckPermission("/openGovernment/ogPublicGuidance/detail")
    @GetMapping("/openGovernment/ogPublicGuidance/detail")
    public CommonResult<OgPublicGuidance> detail(@Valid OgPublicGuidanceIdParam ogPublicGuidanceIdParam) {
        return CommonResult.data(ogPublicGuidanceService.detail(ogPublicGuidanceIdParam));
    }


    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogPublicGuidance/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgPubleGuidanceAndStatusParam> ogPolicyFileIdParamList) {
        ogPublicGuidanceService.enableAndDisable(ogPolicyFileIdParamList);
        return CommonResult.ok();
    }



    /**
     * 网站获取公开指南管理表最新的公告内容+附件
     *
     * @author hjc
     * @date  2024/05/20 17:32
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站获取公告内容+附件")
    //@SaCheckPermission("/openGovernment/ogPublicGuidance/detail")
    @GetMapping("/openGovernment/ogPublicGuidance/getNewContentAndAttachments")
    public CommonResult<OgPublicGuidance> getNewContentAndAttachments() {
        return CommonResult.data(ogPublicGuidanceService.getNewContentAndAttachments());
    }
}
