/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPublicGuidance.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPublicGuidance.param.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogPublicGuidance.entity.OgPublicGuidance;
import com.unis.openGovernment.modular.ogPublicGuidance.mapper.OgPublicGuidanceMapper;
import com.unis.openGovernment.modular.ogPublicGuidance.service.OgPublicGuidanceService;

import java.util.List;

/**
 * 公开指南管理表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/20 17:32
 **/
@Service
public class OgPublicGuidanceServiceImpl extends ServiceImpl<OgPublicGuidanceMapper, OgPublicGuidance> implements OgPublicGuidanceService {

    @Autowired
    private OgPublicGuidanceMapper ogPublicGuidanceMapper;

    @Override
    public Page<OgPublicGuidance> page(OgPublicGuidancePageParam ogPublicGuidancePageParam) {
        QueryWrapper<OgPublicGuidance> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogPublicGuidancePageParam.getTitle())) {
            queryWrapper.like("title", ogPublicGuidancePageParam.getTitle());
        }
        if (ObjectUtil.isAllNotEmpty(ogPublicGuidancePageParam.getSortField(), ogPublicGuidancePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPublicGuidancePageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPublicGuidancePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPublicGuidancePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPublicGuidance::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgPublicGuidanceAddParam ogPublicGuidanceAddParam) {
        OgPublicGuidance ogPublicGuidance = BeanUtil.toBean(ogPublicGuidanceAddParam, OgPublicGuidance.class);
        this.save(ogPublicGuidance);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgPublicGuidanceEditParam ogPublicGuidanceEditParam) {
        OgPublicGuidance ogPublicGuidance = this.queryEntity(ogPublicGuidanceEditParam.getId());
        BeanUtil.copyProperties(ogPublicGuidanceEditParam, ogPublicGuidance);
        this.updateById(ogPublicGuidance);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgPublicGuidanceIdParam> ogPublicGuidanceIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogPublicGuidanceIdParamList, OgPublicGuidanceIdParam::getId));
    }

    @Override
    public OgPublicGuidance detail(OgPublicGuidanceIdParam ogPublicGuidanceIdParam) {
        return this.queryEntity(ogPublicGuidanceIdParam.getId());
    }

    @Override
    public OgPublicGuidance queryEntity(String id) {
        OgPublicGuidance ogPublicGuidance = this.getById(id);
        if (ObjectUtil.isEmpty(ogPublicGuidance)) {
            throw new CommonException("公开指南管理表不存在，id值为：{}", id);
        }
        return ogPublicGuidance;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgPubleGuidanceAndStatusParam> ogPolicyFileIdParamList) {

        for (OgPubleGuidanceAndStatusParam ogPubleGuidanceAndStatusParam : ogPolicyFileIdParamList) {
            OgPublicGuidance ogPublicGuidance = this.queryEntity(ogPubleGuidanceAndStatusParam.getId());
            ogPublicGuidance.setStatus(ogPubleGuidanceAndStatusParam.getStatus());

            this.updateById(ogPublicGuidance);
        }

    }

    /**
     * 网站获取公开指南管理表最新的公告内容+附件
     *
     * @author hjc
     * @date 2024/05/20 17:32
     */
    @Override
    public OgPublicGuidance getNewContentAndAttachments() {

        LambdaQueryWrapper<OgPublicGuidance> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(OgPublicGuidance::getStatus, 2);
        queryWrapper.orderByDesc(OgPublicGuidance::getCreateTime);
        List<OgPublicGuidance> ogPublicGuidanceList = ogPublicGuidanceMapper.selectList(queryWrapper);
        if (CollectionUtils.isEmpty(ogPublicGuidanceList)) {
            return null;
        }
        return ogPublicGuidanceList.get(0);
    }
}
