/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPublicSystem.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogPublicGuidance.param.OgPubleGuidanceAndStatusParam;
import com.unis.openGovernment.modular.ogPublicSystem.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPublicSystem.entity.OgPublicSystem;
import com.unis.openGovernment.modular.ogPublicSystem.service.OgPublicSystemService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 公开制度管理表控制器
 *
 * @author hjc
 * @date  2024/05/20 17:48
 */
@Api(tags = "公开制度管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgPublicSystemController {

    @Resource
    private OgPublicSystemService ogPublicSystemService;

    /**
     * 获取公开制度管理表分页
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取公开制度管理表分页")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/page")
    @GetMapping("/openGovernment/ogPublicSystem/page")
    public CommonResult<Page<OgPublicSystem>> page(OgPublicSystemPageParam ogPublicSystemPageParam) {
        return CommonResult.data(ogPublicSystemService.page(ogPublicSystemPageParam));
    }

    /**
     * 添加公开制度管理表
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加公开制度管理表")
    @CommonLog("添加公开制度管理表")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/add")
    @PostMapping("/openGovernment/ogPublicSystem/add")
    public CommonResult<String> add(@RequestBody @Valid OgPublicSystemAddParam ogPublicSystemAddParam) {
        ogPublicSystemService.add(ogPublicSystemAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑公开制度管理表
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑公开制度管理表")
    @CommonLog("编辑公开制度管理表")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/edit")
    @PostMapping("/openGovernment/ogPublicSystem/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgPublicSystemEditParam ogPublicSystemEditParam) {
        ogPublicSystemService.edit(ogPublicSystemEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除公开制度管理表
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除公开制度管理表")
    @CommonLog("删除公开制度管理表")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/delete")
    @PostMapping("/openGovernment/ogPublicSystem/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgPublicSystemIdParam> ogPublicSystemIdParamList) {
        ogPublicSystemService.delete(ogPublicSystemIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取公开制度管理表详情
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("管理端，网站 获取公开制度详情")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/detail")
    @GetMapping("/openGovernment/ogPublicSystem/detail")
    public CommonResult<OgPublicSystem> detail(@Valid OgPublicSystemIdParam ogPublicSystemIdParam) {
        return CommonResult.data(ogPublicSystemService.detail(ogPublicSystemIdParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogPublicSystem/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgPublicSystemAndStatusParam> paramCommonValidList) {
        ogPublicSystemService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }


    /**
     * 网站-获取公开制度
     *
     * @author hjc
     * @date  2024/05/20 17:48
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站-获取公开制度")
    //@SaCheckPermission("/openGovernment/ogPublicSystem/detail")
    @GetMapping("/openGovernment/ogPublicSystem/getAll")
    public CommonResult<Page<OgPublicSystem>> getAll(OgPublicSystemPageParam ogPublicSystemPageParam) {
        return CommonResult.data(ogPublicSystemService.getAll(ogPublicSystemPageParam));
    }

}
