/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogPublicSystem.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogPublicSystem.param.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogPublicSystem.entity.OgPublicSystem;
import com.unis.openGovernment.modular.ogPublicSystem.mapper.OgPublicSystemMapper;
import com.unis.openGovernment.modular.ogPublicSystem.service.OgPublicSystemService;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 公开制度管理表Service接口实现类
 *
 * @author hjc
 * @date 2024/05/20 17:48
 **/
@Service
public class OgPublicSystemServiceImpl extends ServiceImpl<OgPublicSystemMapper, OgPublicSystem> implements OgPublicSystemService {

    private static Map<String, Integer> sequenceNumbers = new HashMap<>(); // 映射：仓房代码到顺序号
    private static final int MAX_SEQUENCE_NUMBER = 100000; // 顺序号的最大值
    private static final String DATE_FORMAT = "yyyy";
    private static final DateTimeFormatter DATE_FORMATTER = DateTimeFormatter.ofPattern(DATE_FORMAT);

    @Autowired
    private OgPublicSystemMapper ogPublicSystemMapper;

    @Override
    public Page<OgPublicSystem> page(OgPublicSystemPageParam ogPublicSystemPageParam) {
        QueryWrapper<OgPublicSystem> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogPublicSystemPageParam.getDocumentName())) {
            queryWrapper.like("document_name", ogPublicSystemPageParam.getDocumentName());
        }
        if (ObjectUtil.isAllNotEmpty(ogPublicSystemPageParam.getSortField(), ogPublicSystemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPublicSystemPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPublicSystemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPublicSystemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPublicSystem::getPublishDate);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgPublicSystemAddParam ogPublicSystemAddParam) {
        OgPublicSystem ogPublicSystem = BeanUtil.toBean(ogPublicSystemAddParam, OgPublicSystem.class);

        sequenceNumbers.putIfAbsent("01284", 0);
        // 增加当前货位的顺序号，并在达到最大值时重置为0
        int sequenceNumber = (sequenceNumbers.get("01284") + 1) % MAX_SEQUENCE_NUMBER;
        sequenceNumbers.put("01284", sequenceNumber);
        // 确保顺序号是4位数
        String formattedSequenceNumber = String.format("%05d", sequenceNumber);
        // 获取当前日期并格式化为yyyyMMdd
        String currentDate = LocalDate.now().format(DATE_FORMATTER);
        // 合并、日期和顺序号
        String indexNumber = "01284" + "/" + currentDate + "-" + formattedSequenceNumber;
        ogPublicSystem.setIndexNumber(indexNumber);

        this.save(ogPublicSystem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgPublicSystemEditParam ogPublicSystemEditParam) {
        OgPublicSystem ogPublicSystem = this.queryEntity(ogPublicSystemEditParam.getId());
        BeanUtil.copyProperties(ogPublicSystemEditParam, ogPublicSystem);
        this.updateById(ogPublicSystem);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgPublicSystemIdParam> ogPublicSystemIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogPublicSystemIdParamList, OgPublicSystemIdParam::getId));
    }

    @Override
    public OgPublicSystem detail(OgPublicSystemIdParam ogPublicSystemIdParam) {
        return this.queryEntity(ogPublicSystemIdParam.getId());
    }

    @Override
    public OgPublicSystem queryEntity(String id) {
        OgPublicSystem ogPublicSystem = this.getById(id);
        if (ObjectUtil.isEmpty(ogPublicSystem)) {
            throw new CommonException("公开制度管理表不存在，id值为：{}", id);
        }
        return ogPublicSystem;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date 2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgPublicSystemAndStatusParam> paramCommonValidList) {
        for (OgPublicSystemAndStatusParam ogPublicSystemAndStatusParam : paramCommonValidList) {
            OgPublicSystem ogPublicSystem = this.queryEntity(ogPublicSystemAndStatusParam.getId());
            ogPublicSystem.setStatus(ogPublicSystemAndStatusParam.getStatus());

            this.updateById(ogPublicSystem);
        }
    }

    /**
     * 网站-获取公开制度
     *
     * @author hjc
     * @date 2024/05/20 17:48
     */
    @Override
    public Page<OgPublicSystem> getAll(OgPublicSystemPageParam ogPublicSystemPageParam) {

        QueryWrapper<OgPublicSystem> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgPublicSystem::getStatus, 2);
        if (ObjectUtil.isAllNotEmpty(ogPublicSystemPageParam.getSortField(), ogPublicSystemPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogPublicSystemPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogPublicSystemPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogPublicSystemPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgPublicSystem::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);

    }
}
