/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogWorkAnnualReport.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.openGovernment.modular.ogPublicSystem.param.OgPublicSystemAndStatusParam;
import com.unis.openGovernment.modular.ogWorkAnnualReport.param.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogWorkAnnualReport.entity.OgWorkAnnualReport;
import com.unis.openGovernment.modular.ogWorkAnnualReport.service.OgWorkAnnualReportService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 政务公开-工作年报管理表控制器
 *
 * @author hjc
 * @date  2024/05/22 16:55
 */
@Api(tags = "政务公开-工作年报管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class OgWorkAnnualReportController {

    @Resource
    private OgWorkAnnualReportService ogWorkAnnualReportService;

    /**
     * 获取政务公开-工作年报管理表分页
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取政务公开-工作年报管理表分页")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/page")
    @GetMapping("/openGovernment/ogWorkAnnualReport/page")
    public CommonResult<Page<OgWorkAnnualReport>> page(OgWorkAnnualReportPageParam ogWorkAnnualReportPageParam) {
        return CommonResult.data(ogWorkAnnualReportService.page(ogWorkAnnualReportPageParam));
    }

    /**
     * 添加政务公开-工作年报管理表
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加政务公开-工作年报管理表")
    @CommonLog("添加政务公开-工作年报管理表")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/add")
    @PostMapping("/openGovernment/ogWorkAnnualReport/add")
    public CommonResult<String> add(@RequestBody @Valid OgWorkAnnualReportAddParam ogWorkAnnualReportAddParam) {
        ogWorkAnnualReportService.add(ogWorkAnnualReportAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑政务公开-工作年报管理表
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑政务公开-工作年报管理表")
    @CommonLog("编辑政务公开-工作年报管理表")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/edit")
    @PostMapping("/openGovernment/ogWorkAnnualReport/edit")
    public CommonResult<String> edit(@RequestBody @Valid OgWorkAnnualReportEditParam ogWorkAnnualReportEditParam) {
        ogWorkAnnualReportService.edit(ogWorkAnnualReportEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除政务公开-工作年报管理表
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除政务公开-工作年报管理表")
    @CommonLog("删除政务公开-工作年报管理表")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/delete")
    @PostMapping("/openGovernment/ogWorkAnnualReport/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<OgWorkAnnualReportIdParam> ogWorkAnnualReportIdParamList) {
        ogWorkAnnualReportService.delete(ogWorkAnnualReportIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取政务公开-工作年报管理表详情
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取政务公开-工作年报管理表详情")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/detail")
    @GetMapping("/openGovernment/ogWorkAnnualReport/detail")
    public CommonResult<OgWorkAnnualReport> detail(@Valid OgWorkAnnualReportIdParam ogWorkAnnualReportIdParam) {
        return CommonResult.data(ogWorkAnnualReportService.detail(ogWorkAnnualReportIdParam));
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("启用，禁用")
    @CommonLog("启用，禁用")
    //@SaCheckPermission("/openGovernment/ogPolicyFile/enableAndDisable")
    @PostMapping("/openGovernment/ogWorkAnnualReport/enableAndDisable")
    public CommonResult<String> enableAndDisable(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                 CommonValidList<OgWorkAnnualReportAndStatusParam> paramCommonValidList) {
        ogWorkAnnualReportService.enableAndDisable(paramCommonValidList);
        return CommonResult.ok();
    }



    /**
     * 网站-获取工作年报
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("网站-获取工作年报")
    //@SaCheckPermission("/openGovernment/ogWorkAnnualReport/detail")
    @GetMapping("/openGovernment/ogWorkAnnualReport/getAll")
    public CommonResult<Page<OgWorkAnnualReport>> getAll(OgWorkAnnualReportPageParam ogWorkAnnualReportPageParam) {
        return CommonResult.data(ogWorkAnnualReportService.getAll(ogWorkAnnualReportPageParam));
    }

}
