/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.openGovernment.modular.ogWorkAnnualReport.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.common.pojo.CommonValidList;
import com.unis.openGovernment.modular.ogWorkAnnualReport.param.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.openGovernment.modular.ogWorkAnnualReport.entity.OgWorkAnnualReport;
import com.unis.openGovernment.modular.ogWorkAnnualReport.mapper.OgWorkAnnualReportMapper;
import com.unis.openGovernment.modular.ogWorkAnnualReport.service.OgWorkAnnualReportService;

import java.util.List;

/**
 * 政务公开-工作年报管理表Service接口实现类
 *
 * @author hjc
 * @date  2024/05/22 16:55
 **/
@Service
public class OgWorkAnnualReportServiceImpl extends ServiceImpl<OgWorkAnnualReportMapper, OgWorkAnnualReport> implements OgWorkAnnualReportService {


    @Autowired
    private OgWorkAnnualReportMapper ogWorkAnnualReportMapper;
    @Override
    public Page<OgWorkAnnualReport> page(OgWorkAnnualReportPageParam ogWorkAnnualReportPageParam) {
        QueryWrapper<OgWorkAnnualReport> queryWrapper = new QueryWrapper<>();
        if (StringUtils.isNotEmpty(ogWorkAnnualReportPageParam.getTitle())){
            queryWrapper.like("title",ogWorkAnnualReportPageParam.getTitle());
        }
        if(ObjectUtil.isAllNotEmpty(ogWorkAnnualReportPageParam.getSortField(), ogWorkAnnualReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogWorkAnnualReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogWorkAnnualReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogWorkAnnualReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgWorkAnnualReport::getPublishTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(OgWorkAnnualReportAddParam ogWorkAnnualReportAddParam) {
        OgWorkAnnualReport ogWorkAnnualReport = BeanUtil.toBean(ogWorkAnnualReportAddParam, OgWorkAnnualReport.class);
        this.save(ogWorkAnnualReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(OgWorkAnnualReportEditParam ogWorkAnnualReportEditParam) {
        OgWorkAnnualReport ogWorkAnnualReport = this.queryEntity(ogWorkAnnualReportEditParam.getId());
        BeanUtil.copyProperties(ogWorkAnnualReportEditParam, ogWorkAnnualReport);
        this.updateById(ogWorkAnnualReport);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<OgWorkAnnualReportIdParam> ogWorkAnnualReportIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(ogWorkAnnualReportIdParamList, OgWorkAnnualReportIdParam::getId));
    }

    @Override
    public OgWorkAnnualReport detail(OgWorkAnnualReportIdParam ogWorkAnnualReportIdParam) {
        return this.queryEntity(ogWorkAnnualReportIdParam.getId());
    }

    @Override
    public OgWorkAnnualReport queryEntity(String id) {
        OgWorkAnnualReport ogWorkAnnualReport = this.getById(id);
        if(ObjectUtil.isEmpty(ogWorkAnnualReport)) {
            throw new CommonException("政务公开-工作年报管理表不存在，id值为：{}", id);
        }
        return ogWorkAnnualReport;
    }

    /**
     * 启用，禁用
     *
     * @author hjc
     * @date  2024/05/20 16:18
     */
    @Override
    public void enableAndDisable(CommonValidList<OgWorkAnnualReportAndStatusParam> paramCommonValidList) {

        for (OgWorkAnnualReportAndStatusParam ogWorkAnnualReportAndStatusParam : paramCommonValidList) {

            OgWorkAnnualReport ogWorkAnnualReport = this.queryEntity(ogWorkAnnualReportAndStatusParam.getId());
            ogWorkAnnualReport.setStatus(ogWorkAnnualReportAndStatusParam.getStatus());

            this.updateById(ogWorkAnnualReport);
        }

    }

    /**
     * 网站-获取工作年报
     *
     * @author hjc
     * @date  2024/05/22 16:55
     */
    @Override
    public Page<OgWorkAnnualReport> getAll(OgWorkAnnualReportPageParam ogWorkAnnualReportPageParam) {
        QueryWrapper<OgWorkAnnualReport> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(OgWorkAnnualReport::getStatus,2);
        if(ObjectUtil.isAllNotEmpty(ogWorkAnnualReportPageParam.getSortField(), ogWorkAnnualReportPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(ogWorkAnnualReportPageParam.getSortOrder());
            queryWrapper.orderBy(true, ogWorkAnnualReportPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(ogWorkAnnualReportPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(OgWorkAnnualReport::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }
}
