/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.organization.modular.iodepartmentfunction.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.importantNews.modular.sinstatecouncilnotice.entity.BizSinStateCouncilNotice;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.organization.modular.iodepartmentfunction.entity.BizIoDepartmentFunction;
import com.unis.organization.modular.iodepartmentfunction.param.BizIoDepartmentFunctionAddParam;
import com.unis.organization.modular.iodepartmentfunction.param.BizIoDepartmentFunctionEditParam;
import com.unis.organization.modular.iodepartmentfunction.param.BizIoDepartmentFunctionIdParam;
import com.unis.organization.modular.iodepartmentfunction.param.BizIoDepartmentFunctionPageParam;
import com.unis.organization.modular.iodepartmentfunction.service.BizIoDepartmentFunctionService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 机构概况-职能信息管理表控制器
 *
 * @author shine
 * @date  2024/05/21 14:25
 */
@Api(tags = "机构概况-职能信息管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizIoDepartmentFunctionController {

    @Resource
    private BizIoDepartmentFunctionService bizIoDepartmentFunctionService;

    /**
     * 获取机构概况-职能信息管理表分页
     *
     * @author shine
     * @date  2024/05/21 14:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取机构概况-职能信息管理表分页")
    @GetMapping("/organization/iodepartmentfunction/page")
    public CommonResult<Page<BizIoDepartmentFunction>> page(BizIoDepartmentFunctionPageParam bizIoDepartmentFunctionPageParam) {
        return CommonResult.data(bizIoDepartmentFunctionService.page(bizIoDepartmentFunctionPageParam));
    }

    /**
     * 添加机构概况-职能信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加机构概况-职能信息管理表")
    @CommonLog("添加机构概况-职能信息管理表")
    @PostMapping("/organization/iodepartmentfunction/add")
    public CommonResult<String> add(@RequestBody @Valid BizIoDepartmentFunctionAddParam bizIoDepartmentFunctionAddParam) {
        bizIoDepartmentFunctionService.add(bizIoDepartmentFunctionAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑机构概况-职能信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:25
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑机构概况-职能信息管理表")
    @CommonLog("编辑机构概况-职能信息管理表")
    @PostMapping("/organization/iodepartmentfunction/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizIoDepartmentFunctionEditParam bizIoDepartmentFunctionEditParam) {
        bizIoDepartmentFunctionService.edit(bizIoDepartmentFunctionEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除机构概况-职能信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除机构概况-职能信息管理表")
    @CommonLog("删除机构概况-职能信息管理表")
    @PostMapping("/organization/iodepartmentfunction/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizIoDepartmentFunctionIdParam> bizIoDepartmentFunctionIdParamList) {
        bizIoDepartmentFunctionService.delete(bizIoDepartmentFunctionIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取机构概况-职能信息管理表详情
     *
     * @author shine
     * @date  2024/05/21 14:25
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取机构概况-职能信息管理表详情")
    @GetMapping("/organization/iodepartmentfunction/detail")
    public CommonResult<BizIoDepartmentFunction> detail(@Valid BizIoDepartmentFunctionIdParam bizIoDepartmentFunctionIdParam) {
        return CommonResult.data(bizIoDepartmentFunctionService.detail(bizIoDepartmentFunctionIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/organization/iodepartmentfunction/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizIoDepartmentFunction> list) {
        bizIoDepartmentFunctionService.batchUpdateStatus(list);
        return CommonResult.ok();
    }

    /**
     * 门户端
     * 机构概况--机构职能
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("(门户)机构概况--机构职能")
    @GetMapping("/organization/iodepartmentfunction/getList")
    public CommonResult<Map<Integer,List<BizIoDepartmentFunction>>> getList() {
        return CommonResult.data(bizIoDepartmentFunctionService.getList());
    }
}
