/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.organization.modular.ioleaderinfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.organization.modular.iodepartmentfunction.entity.BizIoDepartmentFunction;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.organization.modular.ioleaderinfo.entity.BizIoLeaderInfo;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoAddParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoEditParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoIdParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoPageParam;
import com.unis.organization.modular.ioleaderinfo.service.BizIoLeaderInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 机构概况-领导信息管理表控制器
 *
 * @author shine
 * @date  2024/05/21 14:22
 */
@Api(tags = "机构概况-领导信息管理表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizIoLeaderInfoController {

    @Resource
    private BizIoLeaderInfoService bizIoLeaderInfoService;

    /**
     * 获取机构概况-领导信息管理表分页
     *
     * @author shine
     * @date  2024/05/21 14:22
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取机构概况-领导信息管理表分页")
    @GetMapping("/organization/ioleaderinfo/page")
    public CommonResult<Page<BizIoLeaderInfo>> page(BizIoLeaderInfoPageParam bizIoLeaderInfoPageParam) {
        return CommonResult.data(bizIoLeaderInfoService.page(bizIoLeaderInfoPageParam));
    }

    /**
     * 添加机构概况-领导信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:22
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加机构概况-领导信息管理表")
    @CommonLog("添加机构概况-领导信息管理表")
    @PostMapping("/organization/ioleaderinfo/add")
    public CommonResult<String> add(@RequestBody @Valid BizIoLeaderInfoAddParam bizIoLeaderInfoAddParam) {
        bizIoLeaderInfoService.add(bizIoLeaderInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑机构概况-领导信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:22
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑机构概况-领导信息管理表")
    @CommonLog("编辑机构概况-领导信息管理表")
    @PostMapping("/organization/ioleaderinfo/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizIoLeaderInfoEditParam bizIoLeaderInfoEditParam) {
        bizIoLeaderInfoService.edit(bizIoLeaderInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除机构概况-领导信息管理表
     *
     * @author shine
     * @date  2024/05/21 14:22
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除机构概况-领导信息管理表")
    @CommonLog("删除机构概况-领导信息管理表")
    @PostMapping("/organization/ioleaderinfo/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizIoLeaderInfoIdParam> bizIoLeaderInfoIdParamList) {
        bizIoLeaderInfoService.delete(bizIoLeaderInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取机构概况-领导信息管理表详情
     *
     * @author shine
     * @date  2024/05/21 14:22
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取机构概况-领导信息管理表详情")
    @GetMapping("/organization/ioleaderinfo/detail")
    public CommonResult<BizIoLeaderInfo> detail(@Valid BizIoLeaderInfoIdParam bizIoLeaderInfoIdParam) {
        return CommonResult.data(bizIoLeaderInfoService.detail(bizIoLeaderInfoIdParam));
    }

    /**
     * 批量启用 禁用
     * @author shine
     * @date  2024/05/20 15:34
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("批量启用、禁用")
    @CommonLog("批量启用、禁用")
    @PostMapping("/organization/ioleaderinfo/batchUpdateStatus")
    public CommonResult<String> batchUpdateStatus(@RequestBody List<BizIoLeaderInfo> list) {
        bizIoLeaderInfoService.batchUpdateStatus(list);
        return CommonResult.ok();
    }
}
