/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.organization.modular.ioleaderinfo.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.homePage.modular.hmcarousel.mapper.BizHmCarouselMapper;
import com.unis.organization.modular.iodepartmentfunction.entity.BizIoDepartmentFunction;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.organization.modular.ioleaderinfo.entity.BizIoLeaderInfo;
import com.unis.organization.modular.ioleaderinfo.mapper.BizIoLeaderInfoMapper;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoAddParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoEditParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoIdParam;
import com.unis.organization.modular.ioleaderinfo.param.BizIoLeaderInfoPageParam;
import com.unis.organization.modular.ioleaderinfo.service.BizIoLeaderInfoService;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 机构概况-领导信息管理表Service接口实现类
 *
 * @author shine
 * @date  2024/05/21 14:22
 **/
@Service
public class BizIoLeaderInfoServiceImpl extends ServiceImpl<BizIoLeaderInfoMapper, BizIoLeaderInfo> implements BizIoLeaderInfoService {

    @Resource
    private BizIoLeaderInfoMapper bizIoLeaderInfoMapper;

    @Override
    public Page<BizIoLeaderInfo> page(BizIoLeaderInfoPageParam bizIoLeaderInfoPageParam) {
        QueryWrapper<BizIoLeaderInfo> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(bizIoLeaderInfoPageParam.getLeaderName())) {
            queryWrapper.lambda().like(BizIoLeaderInfo::getLeaderName, bizIoLeaderInfoPageParam.getLeaderName());
        }
        if(ObjectUtil.isNotEmpty(bizIoLeaderInfoPageParam.getLeaderPositionId())) {
            queryWrapper.lambda().eq(BizIoLeaderInfo::getLeaderPositionId, bizIoLeaderInfoPageParam.getLeaderPositionId());
        }
        if(ObjectUtil.isNotEmpty(bizIoLeaderInfoPageParam.getStatus())) {
            queryWrapper.lambda().eq(BizIoLeaderInfo::getStatus, bizIoLeaderInfoPageParam.getStatus());
        }
        if(ObjectUtil.isAllNotEmpty(bizIoLeaderInfoPageParam.getSortField(), bizIoLeaderInfoPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizIoLeaderInfoPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizIoLeaderInfoPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizIoLeaderInfoPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByDesc(BizIoLeaderInfo::getCreateTime);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizIoLeaderInfoAddParam bizIoLeaderInfoAddParam) {
        BizIoLeaderInfo bizIoLeaderInfo = BeanUtil.toBean(bizIoLeaderInfoAddParam, BizIoLeaderInfo.class);
        this.save(bizIoLeaderInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizIoLeaderInfoEditParam bizIoLeaderInfoEditParam) {
        BizIoLeaderInfo bizIoLeaderInfo = this.queryEntity(bizIoLeaderInfoEditParam.getId());
        BeanUtil.copyProperties(bizIoLeaderInfoEditParam, bizIoLeaderInfo);
        this.updateById(bizIoLeaderInfo);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizIoLeaderInfoIdParam> bizIoLeaderInfoIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizIoLeaderInfoIdParamList, BizIoLeaderInfoIdParam::getId));
    }

    @Override
    public BizIoLeaderInfo detail(BizIoLeaderInfoIdParam bizIoLeaderInfoIdParam) {
        return this.queryEntity(bizIoLeaderInfoIdParam.getId());
    }

    @Override
    public BizIoLeaderInfo queryEntity(String id) {
        BizIoLeaderInfo bizIoLeaderInfo = this.getById(id);
        if(ObjectUtil.isEmpty(bizIoLeaderInfo)) {
            throw new CommonException("机构概况-领导信息管理表不存在，id值为：{}", id);
        }
        return bizIoLeaderInfo;
    }

    @Override
    public void batchUpdateStatus(List<BizIoLeaderInfo> list) {

        for(BizIoLeaderInfo bizIoLeaderInfo:list){
            this.updateById(bizIoLeaderInfo);
        }
    }
}
