/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.dev.modular.job.task;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.unis.common.timer.CommonTimerTaskRunner;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.entity.IcPublicOpinionCollect;
import com.unis.interactiveCommunication.modular.icPublicOpinionCollect.mapper.IcPublicOpinionCollectMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.Date;
import java.util.List;

/**
 * 民意征集定时任务--每5分钟一次
 *
 * @author xuyuxiang
 * @date 2022/8/5 15:52
 **/
@Slf4j
@Component
public class IcPublicOpinionCollectTask implements CommonTimerTaskRunner {


    @Autowired
    private IcPublicOpinionCollectMapper icPublicOpinionCollectMapper;

    @Override
    public void action() {

        log.info("================民意征集定时任务开始执行================");


        List<IcPublicOpinionCollect> icPublicOpinionCollectList = icPublicOpinionCollectMapper
                .selectList(Wrappers.lambdaQuery(IcPublicOpinionCollect.class)
               .eq(IcPublicOpinionCollect::getStatus, 2)
                        .in(IcPublicOpinionCollect::getProgressStatus,0,1));

        if (CollectionUtils.isEmpty(icPublicOpinionCollectList)) {
            log.info("暂无找到符合条件的数据");
            return;
        }
        //不为空，就将符合条件“未开始”的民意征集改为“征集中”
        //符合条件“征集中的民意征集改为‘’已过期”
        for (IcPublicOpinionCollect icPublicOpinionCollect : icPublicOpinionCollectList) {

            LocalDateTime now = LocalDateTime.now();

            Instant startInstant = icPublicOpinionCollect.getStartTime().toInstant();
            LocalDateTime startTime = startInstant.atZone(ZoneId.systemDefault()).toLocalDateTime();

            Instant endInstant = icPublicOpinionCollect.getEndTime().toInstant();
            LocalDateTime endTime = endInstant.atZone(ZoneId.systemDefault()).toLocalDateTime();
            if (!now.isBefore(startTime) && !now.isAfter(endTime)) {
                //当前时间在指定时间范围内  改为征集中
                icPublicOpinionCollect.setProgressStatus(1);
                icPublicOpinionCollectMapper.updateById(icPublicOpinionCollect);
            }

            if (now.isAfter(endTime)) {
                //当前时间在结束时间之后  改为已过期
                icPublicOpinionCollect.setProgressStatus(2);
                icPublicOpinionCollectMapper.updateById(icPublicOpinionCollect);

            }

        }




    }
}
